function press = press(theta) 
%----------------------------------------------------------------
% Routine     : press.m 
%
% Description : the theta which gives press=0 is the maximum useful 
%               angle for an element in a probe. Based on
%               Selfridge, Kino, Khuri-Yakub, Appl. Phys Letters 
%               37(1), 1. July 1980
%               using an average of rigid and soft baffle
%               
% Language    : Matlab V4.2
% Written by  : Dept. of Informatics, Univ. Oslo, Sverre Holm
%
% Version no. : 1.0 14.05.97 SH  First version
%               1.1 16.05.97 SH  renamed 'global d' to 'global width'
%
% Called by   : curved.m
% Calling     : -
%------
global width limit

%
% width = element width in wavelengths
% theta = angle in radians
% limit = how far down on element angularity opening angle is defined
%         e.g. limit = 0.5 for -6 dB
%

press = (sin(pi*width*sin(theta))./(pi*width*sin(theta))).*(0.5*cos(theta)+.5)- limit;
return
