%------------------------------------------------------------------------
% Routine         : apodannu.m 
%
% Description     : Computes apodization for annular array
% 
% Language        : Matlab 4.1
% Written by      : Vebjoern Berre (IBT)  
% 
% Version no.     : 1.0 VEB 20.04.93  First Version
% Version no.	  : 1.1 FT  03.09.93  User-Defined Apodiziation included
%				      Removed correction factor for Equal
%				      width (Orignial version was wrong)
% Version no.	  : 1.2 FT  28.09.93  Included Apodization for arbitrary
%				      width.
%                   1.3 HGJ 29.01.97  Test for Bessel transducer
% Called by       : apod
% Calling	  :
%------------------------------------------------------------------------

function [apod_weight]=...
    apodannu(transducer, excitation, elem_pts)
%
% apodization gives the same value for all points in an element
% (in practice apodization is not used for annular arrays)

%--------------------------------------------------------
% convert parameters:
%
Npts=max(size(elem_pts)); 		% # of points
Nelem=transducer(2); 			% # of elements
d=transducer(1); 			% array aperture

apod_numb=excitation(5);
apod_weight = zeros(1,Npts);
%
% find phase center of each element by averaging over all points in element:
%

n=[1:Nelem];
if (transducer(18) == 0 | transducer(18) == 4   ),     % new
% 
% equal area
%
	centers_xy=d/2*sqrt((n-.5)./Nelem);
elseif (transducer(18) == 1),
%
% equal width ?
%
	centers_xy=(d/2)*(n-.5)./Nelem;

elseif (transducer(18)==3)
%
% arbitrary width
% The width of each ring is not stored in a variable
% The following should however find the centers to a good
% approximation if sufficent no. of points are used

	for nn = 1:Nelem
	   ind = find(elem_pts(4,:)==nn);
	   minwidth = ...
	      min(sqrt(elem_pts(1,ind).^2 + elem_pts(2,ind).^2));
	   maxwidth = ...
	      max(max(abs(elem_pts(1,ind))),max(abs(elem_pts(2,ind))));
	   centers_xy(nn) = (minwidth + maxwidth)/2;
	end
end

%
% find apodization for each element
%
if apod_numb == 1, 			% hamming
  apod_weight_short = 0.54-0.46*cos(pi*centers_xy./(d/2)+pi);
elseif apod_numb == 2, 			% hanning
  apod_weight_short = 0.5-0.5*cos(pi*centers_xy./(d/2)+pi);
elseif apod_numb == 3,
  disp(['WARNING: Kaiser apodization not implemented.'])
  apod_weight_short = boxcar(2*Nelem-1);     
elseif apod_numb == 4,
  disp(' Type relative Amplitude for each ring; The Amplitude will be normalized')
  disp(' to an avarage of 1')
  disp([' Ring no.1 = Inner ring, Ring no.',num2str(Nelem),' = Outer Ring'])
  apod_weight_short = zeros(Nelem,1);
  for n=1:Nelem
	apod_weight_short(n) = input([' Type Amplitude for Ring no.',num2str(n),' : ']);
  end
else, 
  apod_weight_short = boxcar(2*Nelem-1);     
end

%
% find apodization-values for each point
if (transducer(18) == 0 ),
for n=1:Nelem
  ind=find( elem_pts(4,:)==n );
  if isempty(ind)
    disp(' ')
    disp('---------      WARNING:   ----------')
    disp(['No points in element # ',num2str(n)])
    disp('Increase the number of points!')
    disp(' ')
  else
    pts_cor=(Npts/Nelem)/length(ind);
    apod_weight(ind)=pts_cor*apod_weight_short(n).*ones(size(ind));
  end
end
else
for n=1:Nelem
  ind=find( elem_pts(4,:)==n );
  if isempty(ind)
    disp(' ')
    disp('---------      WARNING:   ----------')
    disp(['No points in element # ',num2str(n)])
    disp('Increase the number of points!')
    disp(' ')
  else
    pts_cor=1;
    apod_weight(ind)=pts_cor*apod_weight_short(n).*ones(size(ind));
  end
end
end







