%------------------------------------------------------------------------
% Routine         : apodrect.m 
%
% Description     : Computes apodization
% 
% Language    : Matlab 4.0
% Written by  : Vingmed sound A/S, Trond Kleveland
%
% Version no. : 1.0 TKL 28.09.90  
% Version no. : 1.1 TKL 07.09.91  
% Version no. : 2.0 VEB 18.02.93  
% Version no. : 2.1 SH  01.04.93 Rewritten 
% Version no. : 2.2 VEB 22.04.93 
% Version no. : 2.3 TKL 03.09.93 Removed unused code 
% Version no. : 2.4 JOE 16.04.94 Disable apodization of thinned elements
%               2.5 SH  16.05.95 Corrected apodization of thinned elements,
%               2D array
%
% Called by   : apod
% Calling     : apodrect, apodannu
%----------------------------------------------------------------

function [apod_weight,apod_weight_az,apod_weight_el]=...
		apodrect(transducer, excitation, elem_pts)

%
% SH: 26. March 1993:
%
% azimuth apodization gives the same value for all points in an element
% (since it is always applied electronically)
%
% elevation apodization is only applied to center element 
% and requires several points (it is assumed to be applied acoustically)
%
% convert parameters:
%
    N=max(size(elem_pts(1,:)));
    Mm=transducer(6); % elevation elements
    M_el=transducer(7); % No of elevation points;
    Nn=transducer(2); % azimuth elements
    d=transducer(1);  % azimuth aperture
    a=transducer(5);  % elevation aperture 
    ai=transducer(12);% elevation inner element aperture 

    apod_numb=excitation(5);
    apod_numb_el=excitation(6);
%
% azimuth apodization:
%
    if apod_numb == 1,
	apod_weight_az = hamming(Nn); 
    elseif apod_numb == 2,
	apod_weight_az = hanning(Nn);
     elseif apod_numb == 3,
	apod_weight_az=kaiser(Nn,.1102*(82-8.7));
     else, 
	apod_weight_az = boxcar(Nn);     
    end
%
% elevation apodization
%
   if (M_el > 1),	
    if apod_numb_el == 1,
	apod_weight_el = hamming(M_el);   
    elseif apod_numb_el == 2,
	apod_weight_el = hanning(M_el);
     elseif apod_numb_el == 3,
	apod_weight_el = kaiser(M_el,.1102*(82-8.7));
     else, 
	apod_weight_el = boxcar(M_el);     
    end
   else
    	apod_weight_el = 1; 
   end
%
%
	apod_weight = ones(1,N);
 	for n = 1:N,
		
		naz = elem_pts(4,n);
		mel = elem_pts(5,n);
	
% JOE 16.04.94
	   if (naz <= 0)
		 apod_weight(n) = 0;	
          else 

		if (mel ~= 1)
%
% find point no in center elevation element
% not yet implemented therefore always uniform (none) apod. in elevation
% 26.3.93
%
			apod_weight(n) = apod_weight_az(naz);
		else
			apod_weight(n) = apod_weight_az(naz);
		end
	   end 
	end
%   
	if (apod_numb_el ~=0)
 		disp('Elevation apodization is not yet implemented!');
		apod_numb_el = 0;
	end
 

 













