%------------------------------------------------------------------------
% Routine     : apodud.m
%
% Description : Sets a User Defined amplitude on each point on the
%               transducers surface.
%
% Language    : MATLAB 4.1
% Written by  : Frode Teigen (IBT)
%
% Version no. : 1.0  FT 26.04.94 First Version
% Version no. : 1.1 TKL 04.05.94 Corrected 'apod' to 'apodud'
%               1.5 FT  01.09.94 Added Ud apodization for annular array
%               1.6 SH  26.05.95 User apodization for 2D arrays
%
% Called by   : apod
% Calling     : none
%------------------------------------------------------------------------

function amp = apodud(elem_pts,flagg)

global amp_ud
if isempty(amp_ud)
  disp(' Warning! : Global vector amp_ud is not found');
  return
end

Npts = length(elem_pts(1,:));

if (size(amp_ud,1) == 2) 		% 1D array or annular array

  if flagg(2)==1 			% rectangular array
    for n=1:Npts
      indtemp = find(abs(amp_ud(2,:)*1e-3 - elem_pts(1,n))==...
	  min(abs(amp_ud(2,:)*1e-3 - elem_pts(1,n))));
      amp(n) = amp_ud(1,indtemp(1));
    end
  else           % annular array 
    for n=1:Npts
      rad_dist = sqrt(elem_pts(1,n)^2 + elem_pts(2,n)^2);
      indtemp = find(abs(amp_ud(2,:)*1e-3 - rad_dist)==...
	  min(abs(amp_ud(2,:)*1e-3 - rad_dist)));
      amp(n) = amp_ud(1,indtemp(1));
    end
  end

elseif (size(amp_ud,1) == 3) % 2D array
  ind = find(elem_pts(4,:) > 0);  % find active elements 
  Nzero = length(ind);
  amp=zeros(1,Npts);
  amp(ind) = amp_ud(1,1:Nzero);
else
    disp(' Warning! : Cannot understand size of global vector amp_ud!');
end    

