function [array_resp,energy]=...
bporg(excitation,transducer,media,observasjon,flagg,x,y,z,t,el_pts,centers,...
plotfig,config,option,bpflag,pvec,plength)

%------------------------------------------------------------------------
% Routine         : bporg.m
%
% Description     : Calls bpusim with the parameters to calculate the 
%		    beampattern depending on whether a user-defined pulse
%		    is used or not. Plots the results as chosen by the
%		    the user in the main menu.
%
% Language        : Matlab 4.1
% Written by      : Frode Teigen, IBT.  
%
% Version no.     : 3.0 FT 08.08.93 
% Version no.     : 3.1 EI 15.10.93 Added 'transducer' in call to bpplot
% Version no.	  : 3.2 FT 06.01.93 Normalization of individual user-pulses
%                   3.3 FT 29.04.93 Removing thinned elements
%                   3.4 LO 10.10.95 Normalization of beam profiles removed.
%                                   Beam profiles of different transducers
%                                   can now be compared.
%                   3.5 SH 04.06.96 centers as input and output 
%                   3.6 AA 17.06.97 Added log(... +eps) in calc
%                                   of array_resp (peak-value-calc).
%
% Called by       : usimcnf
% Routines called : bpusim, bpplot
% -----------------------------------------------------------------------
 		
%          DEFINITION OF PARAMETERS
%------------------------------------------------------------------------
indtmp = find(el_pts(4,:)>0);
elem_pts = el_pts(:,indtmp);
f = excitation(1);
pflag = excitation(13);
Weig_numb=excitation(10);
N=length(elem_pts(1,:));

if pflag ~= 0 & bpflag == 0
   disp(' The peak-value of a User Defined Pulse is not implemented');
   disp('    Please use option ''Energy''');
else
  %          CALLING bpusim TO CALCULATE BEAMPATTERN
  %------------------------------------------------------------------------
  if pflag == 0,
    array_resp = bpusim(excitation,transducer,media,observasjon,...
    flagg,x,y,z,t,elem_pts,centers,config,option,bpflag);
  else
    array_resp = bpusim(excitation,transducer,media,observasjon,...
    flagg,x,y,z,t,elem_pts,centers,config,option,bpflag,pvec,plength);
  end
  if bpflag == 1,
    %**********************************************************************
    % 	CALCULATION OF ENERGY AND CALLING bpplot TO PLOT RESULTS
    %     Result not normalized
    %----------------------------------------------------------------------
    energy = sum(real(array_resp).^2);
    % dirty triks:
    % Det er forskjell paa samplingfrekvensen i bp (6*f) og layers (200*f)
    % Energi kurvene blir dermed forskjovet med mindre en ganger med 200/6
    energy=energy*200/6; 
    % Dette trikset kan unngaas hvis vi multipliserer energy med 
    % tiden mellom hvert sample i baade layers og bp.
    % Denne samplingstiden kan normaliseres mot f.eks 1/20MHz s.a.
    % slutt kurvene faar en energy rundt 0 dB  
    % end triks
    energy = 10*log10(energy);
    bpplot(plotfig,transducer,excitation,option,observasjon,flagg,energy);
  else 
    %**********************************************************************
    % 	CALCULATION OF PEAK-VALUES AND CALLING bpplot TO PLOT RESULTS
    %----------------------------------------------------------------------
    global complex_field
    complex_field = array_resp;
    array_resp = 20*log10(abs(array_resp+eps));
    bpplot(plotfig,transducer,excitation,option,observasjon,flagg,array_resp);
  end
end
return

  


