function [array_resp]=...
    bpusim(excitation,transducer,media,observasjon,flagg,x,y,z,t,elem_pts,centers,...
config,option,bpflag,pvec,plength)

%------------------------------------------------------------------------
% Routine         : bpusim.m
%
% Description     : Calls apod.m to find apodizing for each transducer elem.,
% 		    and focus to calculate time-delays for each transducer elem.
%		    Calls beampat to find beampattern (peak or energy depending
%		    on the value of bpflag.).
% 
% Language        : Matlab syntax
% Written by      : Sverre Holm VMS, Tor Arne Reinen, SINTEF-DELAB April 1993  
% Version no.     : 1.0 SH/TAR 01.04.93
%		  : 1.5 SH     15.04.93
%		    2.0 VEB    21.04.93
%		    2.1 FT     23.08.93
%		    2.2 FT     17.01.94 Added c_foc 
%		    2.3 FT     11.02.94 c_foc = excitation(14)
%                   2.4 SH     12.11.94 used abs in normalization of apodization 
%                   2.5 EH     10.03.95 removed redundant display message
%                   2.6 SH     12.04.95 removed redundant code
%                   2.7 SH     18.04.95 Test for complex observasjon-vector
%                   2.8 SH     04.06.96 centers as input, and output to focus
%                   2.9 SH     29.05.97 Matlab 5: removed unused end

% Called by       : bporg
% Routines called : apod, focus, xyz2rhp, plotx0, beampat 
% ----------------------------------------------------------------

figure(config);

%          INFORMATION
%------------------------------------------------------------------------
disp(' *********************** BeamPattern  ***********************')
disp('                      *** bpusim.m ***')
disp('  ')
disp(' Geometry, pulsed excitation, focal point, apodization, and')
disp(' observation points given in the configuration menu')
disp('  ')

%          DEFINITION OF PARAMETERS
%------------------------------------------------------------------------

%       LOCAL FLAGS
show = 0;				% show plots of apodization, delays etc

%       EXCITATION
pflag = excitation(13);
c_foc = excitation(14);  %Sound of speed used when calculating focusing delays.

%	TRANSDUCER
N = max(size(elem_pts));
  
%	AVLEDEDE PARAMETRE
plen=excitation(9)/excitation(1);
%
%
% test for complex observasjon
if any(imag(observasjon))
  disp('WARNING! Complex entries in observation vector, result is not guaranteeed!')
end
  
%          APODIZATION
%---------------------------------------------------------------------------
% input  : transducer,excitation,elem_pts,flagg
% output : apod3

[apod_weight]=apod(transducer, excitation, elem_pts, flagg);

if show==1
  subplot(3,3,1),
  plotx0(elem_pts(2,:),1000*elem_pts(1,:),apod_weight)
  title(['Azimuth : ',num2str(apodtxt(excitation(5)))])
  xlabel('x [mm]')

  subplot(3,3,2),
  plotx0(elem_pts(1,:),1000*elem_pts(2,:),apod_weight)
  if flagg(2)==1
    title(['Elevation : ',num2str(apodtxt(excitation(6)))])
  elseif flagg(2)==3
    title(['Elevation : ',num2str(apodtxt(excitation(5)))]),
    disp(['Remember correction factor for #pts if this doesn''t look right']),
  end
  xlabel('y [mm]')
end

% normalize apodization to sum = number of elements
  
elem_apo = apod_weight;
apod3=N*elem_apo/sum(abs(elem_apo));
if (isempty(elem_apo)), elem_apo, end;	


%          FOCUSING DELAYS
%---------------------------------------------------------------------------
% calculate exact focusing delays
% input  : excitation, media, transducer, elem_pts, flagg
% output : delta_t_rx

[exact_rx,center] = focus(excitation,c_foc,transducer,elem_pts,centers,flagg);


% plot phase-centers:
if show==1 & flagg(2)==1
  subplot(3,3,4)
  plot(1000*center(1,:), 1000*center(2,:),'*')
  xlabel('x')
  ylabel('y')
  title('Phase centers of elements')
  grid
  
  subplot(3,3,5)
  plot(1000*center(2,:), 1000*center(3,:),'*')
  xlabel('y')
  ylabel('z') 
  grid
  
  subplot(3,3,6)
  plot(1000*center(1,:), 1000*center(3,:),'*')
  xlabel('x')
  ylabel('z') 
  grid
elseif show==1 & flagg(2)==3
  subplot(3,1,2)
  plot(1000*center(1,:), 1000*center(2,:),'*')
  xlabel('sqrt(x^2+y^2)')
  ylabel('z')
  title('Phase centers of elements')
  grid
end


%           CALCULATION OF ARRAY-RESP
%--------------------------------------------------------------------------
if pflag==0,
    array_resp=...
    beampat(transducer,excitation,media,observasjon,flagg,x,y,z,t,elem_pts,config,option,exact_rx,apod3,bpflag);
else
%

    array_resp=...
    beampat(transducer,excitation,media,observasjon,flagg,x,y,z,t,elem_pts,config,option,exact_rx,apod3,bpflag,pvec,plength);
end

