%------------------------------------------------------------------------
% Routine     : focus()
%
% Description : masterfile calling focrect or focannu depending 
%                   on flagg(2) : 1 -> rectangular 3 -> annular  
%
% Language    : MATLAB 4.0
% Written by  : Vebjoern Berre (IBT) 
%
% Version no. : 1.0 VEB 22.04.93
% Version no. : 1.1 TKL 30.07.93 Added some comments
% Version no. : 1.2  SH  2.12.93 Added transducer in call of focrect
%             : 2.0 FT  20.04.94 Added phase noise
%             : 2.1 SH  12.04.95 Excitation(2:4) now in polar coordinates
%               2.2 SH  06.04.96 centers is also input to focus and focrect
%               2.3 SH  21.01.97 excitation is input to focrect and focannu
%
% Called by   : beampat, pecomp
%------------------------------------------------------------------------

function [delays,ctr] = focus(excitation,c,transducer,elem_pts,centers,flagg)

%
% input focus parameters
%
     r = excitation(2);
     theta = excitation(3);
     phi = excitation(4);
%
% RECTANGULAR GEOMETRY
%
   if flagg(2)==1
%
% compute exact delays 
%
     [delays,ctr] = focrect(excitation,c,elem_pts,centers,transducer);

%
% ANNULAR GEOMETRY
%
   elseif flagg(2)==3 	

     if theta~=0 | phi~=0
       disp('WARNING: Annular array cannot be steered!')
     end
     [delays,ctr] = focannu(excitation,c,elem_pts,transducer);

   end  

   disp(['Focusing to r = ',num2str(1000*r),' mm, azimuth = ', ...
          num2str(phi*180/pi),' deg, elevation = ', ...
          num2str(theta*180/pi),' deg'])

  if excitation(7)
    delays = phase(excitation,transducer,c,elem_pts,delays);
  end
  



