%------------------------------------------------------------------------
% Routine     : optiwate.m
% Description : Calculating optimal weights for a linear array. Will also
%               calculate weights for some carefully thinned arrays.
% Language    : Matlab 4.2
% Written by  : Jan Ove Erstad , IfI-UiO
%
% Version no. : 1.0 JOE 12.10.94 First version
%               1.1 JOE 21.10.94 Interactive user interface
%               1.2 JOE 16.11.94 Changes call to genremez
%               1.3 BJE 25.04.95 removed ConfigOrigHandle from functioncall
%
%
% Called by   : usimcnf
% Calling     : genremez, ultremez
%
%------------------------------------------------------------------------
function optiwate(elem_pts,transducer,option,media,excitation,flagg,config)
  
  global amp_ud
  figure(config)
  fid     = 1;
  done    = 0;
  frstime = 1;
  done    = 0;
  imp     = [];
  flagstee = 0;
  flagtxt = 'OFF';
  steerang= 0;
  clc
  disp(' ');
  disp('Optimal weights will be put into amp_ud (user def. apodization) vector');
  disp('Choose between routines for uniform and nonuniform arrays by pushing the');
  disp('corresponding key on the keyboard while pointing on the CONFIG window.');
  disp(' ');
  if find(elem_pts(4,:) < 0)
      thi    = find(elem_pts(4,:) < 0);
      percnt =  max(size(thi))/max(size(elem_pts));
      fprintf(fid,['Current array is thinned  ',num2str(100*percnt),...
          ' percent','.\n']);
    else
      disp('Current array has no thinned elements.');
  end 
  disp('Push a key to continue');
  b1  =  ginput(1);
  clear b1
  while ~done
      clc
      if ~frstime 				%if optimization has been performed
          dynam  = [max(abs(imp))/min(abs(imp))] ;
          if ~isempty(dynam)
              disp(['Weight dynamic factor in previous step ',num2str(dynam)]);
          end 
      end 
      disp(' ');
      disp('------------------------------------------- ');
      disp('| Equispaced array    :   1               |');
      disp('| Nonequispaced array :   2               |');
      disp('| Manual calculation  :   3               |');
      disp('|                                         |');
%  disp(['| Steering: ',flagtxt,' -->  Include/disable? : 5 |']);
%  if steerang ~= 0
%    disp(['| Steered to phi [deg]:   ',num2str(steerang),'              |']);
%  end 
      disp('| Quit                :  any other choice |');
      disp('------------------------------------------- ');
      disp(' ');disp('Make your choice:');
      [bt1,bt2,btn] = ginput(1);
      if any(btn == [49 50 51 53]) & ~done
          if ~frstime 			%if optimization has been performed
              disp('Change gridspacing ?  [y/n]');
              [bt1,bt2,butn] = ginput(1);
              if butn == 121
                  disp('New optimizing !');
                  lgrid = input('Give new gridpoint value : ');
                elseif butn == 110
                  disp('New optimizing, unchanged gridpoint value');
              end 
            else
              lgrid = 16; 			%default value of lgrid
          end 
          
          if btn == 49 			%using the Lagrange inerpolator version
              [imp] = ultremez(lgrid,elem_pts,transducer,option,media,excitation,...
                  flagg,config);
            elseif btn == 50 			%using the inverting matrix version
              if flagstee
                  disp('Not included yet!');
%	imp = glenrem(flagstee,steerang,lgrid,elem_pts,transducer,...
%    option,media,excitation,flagg,config);
                else
                  imp = genremez(lgrid,elem_pts,transducer,option,media,excitation,...
                      flagg,config);
              end 
            elseif btn == 53
              if flagstee == 0
                  flagstee = 1; flagtxt = ' ON';
                  steerang= input('Input value of phi [deg] : ');
                  if (isempty(steerang)) | (steerang < 0) | (steerang > 90)
                      disp('Illegal input!');
                  end 	  
                else
                  flagstee = 0; flagtxt = 'OFF';
              end 	
            elseif btn == 51
              disp('You now have a handle to the local datas through the debugger.');
              disp('Return to optimization menu by writing: dbstep (after K>>)');
              keyboard
          end 
          frstime = 0;
        else
          done = 1;
      end  					%if any btn
  end  					%while ~done
  
  if ~isempty(imp)
      imp = imp/max(abs(imp));
      amp_ud = [imp; elem_pts(1,(elem_pts(4,:) >= 0))*1e3]; % apodization
    else
      disp('No apodization is calculated.');
  end 
  pruned = -elem_pts(4,elem_pts(4,:) < 0);
  if ~isempty(pruned)
      fprintf(fid,['Current array is thinned  ',num2str(100*percnt),...
          ' percent','.\n']);
  end 
  disp(' ');
  disp('Finished! -> Returning to UltraSim menu.');
  fprintf('\n');
%------------------------------------------------------------------------
  
  
  
  
  
