%------------------------------------------------------------------------------
% Routine     : apobserv.m
% Description : Radiation from curved array.
%		Defining observation area.
% Language    : Matlab 4.1
% Written by  : Vebjorn Berre, IBT
%
% Version no. : 1.0 VEB 05.10.92
%             : 3.0 VEB 01.04.93
% 	      : 3.1 TKL 07.09.93 Corrected 'if' statement for option
%	      : 3.2 TKL 23.09.93 Plane check if 2. axis is t -> [us]
%             : 3.3 TKL 24.11.93 Allowed yz-plane for PE-analysis
%             : 3.4 FT  11.02.94 Correct #points to be as in obs.menu
%             : 3.5 TKL 21.02.94 Allowed xy-plane for PE-analysis
%             : 3.6 FT  20.03.94 Removed some obs.options & linjeparametre
%	      : 3.7 BJE 11.10.94 Changed if tests Plane, added movie option
%             : 3.8 SH  12.04.95 Added flagg(4)=4 for sin(theta) as axis
%             : 3.9 KE  16.11.95 Added Volumetric Observations .i.e. 3D
%
% Called by   : usimcnf VIA o?usim
% Calling     :	xyz2rhp, rhp2xyz, indfile, k2xyz
%------------------------------------------------------------------------------

function [x,y,z,t]=apobserv(observasjon,option,flagg)
  
  fprintf('\nWAIT: Calculating observation points ')
  
%
% initialize
%
  if flagg(4)==1
      fast=['xyzt'];		% rectangular coordinates
    elseif flagg(4)==3
      fast=['rhpt'];		% spherical coordinates
    else 
      fast=['rest'];            % sin(angles), spherical coordinates
  end

% -----------------------------------
% Volume and volume + movie 
% Added 16/11-95 KE
% -----------------------------------

   if option(1)=='3' | option(1)=='f'
      ind=[1 2 3 4];
      if option(1)=='3' & option(3)=='t'
	 ind(3)=4;
	 ind(4)=3;
      end
      fprintf('> VOLUME')
      if option(1)=='f'
	 fprintf(' (movie)');
      end
      fprintf('\n\n');

      firstlength=(observasjon(5)-observasjon(1));
      secondlength=(observasjon(6)-observasjon(2));
      thirdlength=(observasjon(ind(3)+4)-observasjon(ind(3)));
      tmp1=[0:1e-3/observasjon(15):firstlength]+observasjon(1);
      tmp2=[0:1e-3/observasjon(15):secondlength]+observasjon(2);
      if option(3)=='z'
         tmp3=[0:1e-3/observasjon(15):thirdlength]+observasjon(ind(3));
      elseif option(3)=='t'
 	 tmp3=[0:1e-6/observasjon(15):thirdlength]+observasjon(ind(3)); % time [us]
      end

% The meshgrid is made in the following order to facilitate imaging according
% to the current usage of axes.

      [tmp3,tmp1,tmp2]=meshgrid(tmp3,tmp1,tmp2);
      
      tmp4=ones(size(tmp1))*observasjon(ind(4));

      tmp=find(ind==1);		 
      tmpx=eval(['tmp',num2str(tmp)]);
      tmp=find(ind==2);
      tmpy=eval(['tmp',num2str(tmp)]);
      tmp=find(ind==3);
      tmpz=eval(['tmp',num2str(tmp)]);
      tmp=find(ind==4);
      t=eval(['tmp',num2str(tmp)]);		% "4th" dimension
 

      if flagg(4)==1				% rectangular coordinates
          x=tmpx;
	  y=tmpy;
	  z=tmpz;
        elseif flagg(4)==3			% spherical coordinates
          [x,y,z] = rhp2xyz(tmpx,tmpy,tmpz);
        elseif flagg(4)==4			% spherical coordinates (sine)
          [x,y,z] = k2xyz(tmpx,tmpy,tmpz);	  
      end 
      
%  
% PLANE and PLANE + MOVIE
%
   elseif option(1) == '2' | option(1) == 'm' 	
      ind=indfile(option(2),option(3),fast);
      fprintf('> PLANE')
      if option(1) == 'm' 
          fprintf(' (movie)');	% additional text for movie
      end
      fprintf('\n\n');

      
%
% define 1st and 2nd axis
%
      firstlength=(observasjon(ind(1)+4)-observasjon(ind(1)));
      secondlength=(observasjon(ind(2)+4)-observasjon(ind(2)));
      if all(option(2:3) == 'xz') | all(option(2:3) == 'xy') | ...
         all(option(2:3) == 'yz')
          tmp1=[0:1e-3/observasjon(15):firstlength]+observasjon(ind(1));
          tmp2=[0:1e-3/observasjon(15):secondlength]+observasjon(ind(2));
        elseif all(option(2:3) == 'xt')
          tmp1=[0:1e-3/observasjon(15):firstlength]+observasjon(ind(1));
          tmp2=[0:1e-6/observasjon(15):secondlength]+observasjon(ind(2)); % time [us]
        else
          tmp1=[0:firstlength/(observasjon(9) - 1):firstlength]+observasjon(ind(1));
          tmp2=[0:secondlength/(observasjon(9) - 1):secondlength]+observasjon(ind(2));
          disp('The observation specification does not fit 2D response analysis') 
          disp('Returning to main program')
	  return
      end

%      
% create meshgrid in "4 dimensions"
%

      [tmp1,tmp2]=meshgrid(tmp1,tmp2);

      tmp3=ones(size(tmp1))*observasjon(ind(3));
      tmp4=ones(size(tmp1))*observasjon(ind(4));
      
      tmp=find(ind==1);		 
      tmpx=eval(['tmp',num2str(tmp)]);
      tmp=find(ind==2);
      tmpy=eval(['tmp',num2str(tmp)]);
      tmp=find(ind==3);
      tmpz=eval(['tmp',num2str(tmp)]);
      tmp=find(ind==4);
      t=eval(['tmp',num2str(tmp)]);		% "4th" dimension
      
      if flagg(4)==1				% rectangular coordinates
          x=tmpx;
	  y=tmpy;
	  z=tmpz;
        elseif flagg(4)==3			% spherical coordinates
          [x,y,z] = rhp2xyz(tmpx,tmpy,tmpz);
        elseif flagg(4)==4			% spherical coordinates (sine)
          [x,y,z] = k2xyz(tmpx,tmpy,tmpz);	  
      end 

%      
% LINE - axis or parametric straight line
% 
    elseif option(1)=='1'  
      if flagg(4)==1
          fprintf('> LINE - rectangular coordinates\n\n')
          STOR=sqrt(sum((observasjon([5 6 7])-observasjon([1 2 3])).^2));
          STEP=STOR/(observasjon(9) - 1);
          parameter=[0:STEP:STOR];
          
          x=parameter*(observasjon(5)-observasjon(1))/STOR+observasjon(1);
          y=parameter*(observasjon(6)-observasjon(2))/STOR+observasjon(2);
          z=parameter*(observasjon(7)-observasjon(3))/STOR+observasjon(3);
          t=parameter; 		% implies that c(particle)=1 m/s 
        elseif flagg(4)==3 		
          fprintf('> LINE - spherical coordinates\n\n')
          parameter=[0:1:(observasjon(9) - 1)];
          
          r=parameter*(observasjon(5) - observasjon(1))/...
                 (observasjon(9) - 1) + observasjon(1);
          h=parameter*(observasjon(6) - observasjon(2))/...
                 (observasjon(9) - 1) + observasjon(2);
          p=parameter*(observasjon(7) - observasjon(3))/...
                 (observasjon(9) - 1) + observasjon(3);
          t=parameter*(observasjon(8) - observasjon(4))/...
                 (observasjon(9) - 1) + observasjon(4);
          [x,y,z] = rhp2xyz(r,h,p);
        elseif flagg(4)==4	
          fprintf('> LINE - spherical coordinates, sine(angles)\n\n')
          parameter=[0:1:(observasjon(9) - 1)];
          
          r=parameter*(observasjon(5) - observasjon(1))/...
                 (observasjon(9) - 1) + observasjon(1);
          e=parameter*(observasjon(6) - observasjon(2))/...
                 (observasjon(9) - 1) + observasjon(2);
          s=parameter*(observasjon(7) - observasjon(3))/...
                 (observasjon(9) - 1) + observasjon(3);
          t=parameter*(observasjon(8) - observasjon(4))/...
                 (observasjon(9) - 1) + observasjon(4);
          [x,y,z] = k2xyz(r,e,s);	  
      end
      
%
% POINT
%
    elseif option(1)=='p'
      if flagg(4)==1
          fprintf('> POINT - rectangular coordinates\n\n')
	  x=observasjon(1);
          y=observasjon(2);
          z=observasjon(3);
          t=observasjon(4);
        elseif flagg(4)==3
	  fprintf('> POINT - spherical coordinates\n\n')
          r=observasjon(1);
          h=observasjon(2);
          p=observasjon(3);
          t=observasjon(4);
          [x,y,z] = rhp2xyz(r,h,p);
        elseif flagg(4)==4
	  fprintf('> POINT - spherical coordinates (sine)\n\n')
          r=observasjon(1);
          e=observasjon(2);
          s=observasjon(3);
          t=observasjon(4);
          [x,y,z] = k2xyz(r,h,p);	  
        else
          fprintf('\n\nOnly spherical and rectangular coordinates supported!')
      end
  end

  fprintf('\n')
  

    
  
  
  

