%------------------------------------------------------------------------
% Routine     : busim
%
% Description : Configuring excitation-parameters - beamforming
%
% Language    : MATLAB 4.1
% Written by  : Vebjorn Berre 4/5-93
%
% Version no. : 3.0
% Version no. : 3.1 TKL 13.07.93 Corrected ['xyzt']' to ['xyzt']
% Version no. : 3.2 TKL 27.07.93 Lost one "if" statement in version 3.1
% Version no. : 3.3 FT  02.09.93 Calls menu35 for selection of Apodizing
%				 Added User-Defined Apodizing (Ann. Array)
%	      : 3.4 FT  08.02.94 Added parameters for focussing algorithm
%	                         Parameters displayed dependent on flagg(2)
%             : 3.5 FT  23.02.94 Removed disp('EXIT = "x"')
%               3.6 FT  20.03.94 Phase noise removed -> comments
%               3.7 FT  20.04.94 Included Phase noise 
%               3.8 FT  01.09.94 New text Ud apod for annular array
%               3.9 SH   9. 1.95 Added transducer in call and input of f-number
%               4.0 SH  16.03.95 Corrected spelling error
%               4.1 SH  12.04.95 Added flagg(4)=4 and
%                                excitation(2:4) now in polar coordinates
%               4.2 SH  15.09.95 Small fix for annular array and rect. coord.
%		5.0 NAA 16.12.96 Changes for sub-aperture apodization
%               5.1 SH  17.01.97 excitation(24) for focus type (sph, conical)
%		5.2 NAA 01.05.97 Hybrid focusing
%                                   
% Called by   : usimcnf
% Calling     : xyz2rhp, rhp2xyz, busimtxt, punkt, menu35
%------------------------------------------------------------------------

function excitation = busim(excitation,flagg,transducer)

fid = 1;

tmp=size(excitation);

if tmp(2)<23
	tmp=excitation;
	excitation=zeros(1,23);
	excitation(1:length(tmp))=tmp;
end

if flagg(4)==1
% convert from rectangular coordinates  
  fast=['xyzt'];
  
  [excitation(2),excitation(3),excitation(4)] = ... 
          rhp2xyz(excitation(2),excitation(3),excitation(4));
elseif flagg(4)==3
  fast=['rhpt'];
elseif flagg(4) == 4
  fast=['rest'];
% convert parameters
  excitation(3:4)=sin(excitation(3:4));
end

com1=0;
while com1~='x'
  clc

  busimtxt;
  
  disp('	CHANGE 	= "number"')
  com1 = input('-> Decision (<CR> = exit): ','s');
  if isempty(com1) com1 = 'x'; end
  if length(com1)==1 com1=['0',com1];end
  if length(com1)>2
    com1 = '00'
  end
  

  % changing of parameters

  if (flagg(1)==1 | flagg(1)==3) & flagg(2)==1 & (com1=='02' | com1=='03' | com1=='04')

  %
  % rectangular coordinates, rectangular array
  %
    temp=str2num(com1(2));
    disp(' ')
    disp('Electronic focusing')
    disp('-------------------')
    excitation(temp) = punkt(fast(temp-1),excitation(temp),' ');

  elseif flagg(2)==3 &  flagg(4)==3 | flagg(4) == 4 & com1=='02'
  %
  % spherical coordinates, annular array
  %
    disp(' ')
    disp('Electronic focusing')
    disp('-------------------')
    excitation(2) = input(' Input depth : ')*1e-3;
    
  elseif flagg(2)==3  & flagg(4)==1 & com1=='04'
  %
  % rectangular coordinates, annular array
  %
    disp(' ')
    disp('Electronic focusing')
    disp('-------------------')
    excitation(4) = input(' Input depth : ')*1e-3;  


  elseif flagg(1)==2 & com1=='02'
    temp=input('Number of focal zones   =  ');
    if ~isempty(temp) excitation(2)=temp; end
  elseif com1=='29'
    temp=input('f-number                = ');
    if ~isempty(temp)
      if flagg(4) == 1     % rectangular coordinates
          excitation(4) = temp*transducer(1);          
      elseif flagg(4) == 3 | flagg(4) == 4% spherical coordinates
          excitation(2) = temp*transducer(1);
      end
    end
  elseif com1=='05'
     if flagg(2)==3,
    temp = menu35_0('Choose apodization','No Apodization','Hamming','Hanning',...
	'Kaiser-Bessel','User-Defined (elements)',...
	'User-Defined (points)');
     else  
       temp = menu35_0('Choose apodization','No Apodization','Hamming',...
	   'Hanning','Kaiser-Bessel','User-Defined (points)');
     end
     if ~isempty(temp) excitation(5)=temp; end
       if (temp==4 & flagg(2)==1) | (temp==5 & flagg(2)==3)
	 excitation(6)=0;
	 disp([' User-defined apodization should be defined',...
		 ' in the global']);
	 disp(' vector ''amp_ud'', of the following format : ');
	 disp('     amp_ud(1,:) = Amplitude');
	 if flagg(2)==1
	   disp('     amp_ud(2,:) = x-values in mm');
	 elseif flagg(2)==3
	   disp('     amp_ud(2,:) = radial distance in mm');
	 end
	 disp([' Note that the amplitudes will be normalized '...
		 'to an average of 1']);
	 disp('');
	 disp(' Press any key to continue...');
	 pause;
       end
  elseif com1=='06' & flagg(2)==1
    if excitation(5)==4
      disp([' Apodization in elevation not used when azimuth is '...
	      'User Defined']);
      disp('');
      disp(' Press any key to continue...')
      pause;
    else
      temp = menu35_0('Choose apodization','No Apodization','Hamming',...
	'Hanning','Kaiser-Bessel');
    if ~isempty(temp) excitation(6)=temp; end
    end
  elseif com1=='07'
    temp=menu35_0('Phase Noise','No Phase Noise','Gaussian',...
	'Gaussian with correlation length','User Defined');
    if ~isempty(temp) excitation(7)=temp;end
  elseif com1=='08'
    if excitation(7)==1
      temp=input('Standard deviation [units of lambda] =  ');
    elseif excitation(7)==2
      temp=input('Random seed start number =  ');
    elseif excitation(7)==3
      disp(' User-defined phase noise should be defined in the global');
      disp(' vector ''phase_err_ud'', of the following format : ');
      disp('     phase_err_ud(1,:) = phase deviation in ns');
      disp('     phase_err_ud(2,:) = x-values in mm');
      disp('');
      disp(' Press any key to continue...');
      pause;
    end
    if ~isempty(temp) excitation(8)=temp; end
  elseif com1=='14'
    temp=input('Speed of Sound	=  ');
    if ~isempty(temp) excitation(14)=temp; end
  elseif com1=='15' & flagg(2)==3 & flagg(3)==2
    disp(' Set Transducer Diameter for use in focusing algorithm');
    disp(' for calculation of time delays');
    disp([' Type ''0'' if you want to use the value specified in'...
	  ' the Transducer SubMenu']);
    temp=input(' Diameter	=  ');
    if ~isempty(temp) excitation(15)=temp*1e-3; end
  elseif com1=='16' & flagg(2)==3 & flagg(3)==2
    disp(' Set Transducer Radius of Curvature for use in focusing algorithm ');
    disp(' for calculation of time delays');
    disp([' Type ''0'' if you want to use the value specified in',...
	  ' the Transducer SubMenu']);
    temp=input('Radius of Curvature	=  ');
    if ~isempty(temp) excitation(16)=temp*1e-3; end
  elseif flagg(1)==3 & ( com1=='22' | com1=='23')
    if     com1 == '22', excitation(22) = pi/180*input('Micro steered angle [deg]: ');
    elseif com1 == '23', excitation(23) = input('# of sub apertures: ');
    end
  elseif (com1=='24')
    excitation(24) = input('Focusing type: 0 - spherical, 1 - conical, 2 - hybrid: '); 
  elseif com1=='25' & excitation(24) ~= 0,
    excitation(25) = (pi/180)*input('Axicon angle: [deg] (0 = flat array): '); 
  end
end
  
end

%
% convert to polar coordinates on output
%
if flagg(4)==1
  [excitation(2),excitation(3),excitation(4)] = ... 
       xyz2rhp(excitation(2),excitation(3),excitation(4));
elseif flagg(4)==4
   [excitation(3:4)] = asin(excitation(3:4));
end