%------------------------------------------------------------------------
% Routine     : k2xyz
%
% Description : coordinate transformation from spherical to rectangular
%                   r=Radial, h=tHeta, p=Phi 
%               where angles are given by sin(theta) and sin(phi)
%                   Special feature is that r is allowed to be Inf and NaN,
%                   in such cases x = theta, y = phi and z = Inf
%
% Language    : Matlab 4.1
% Written by  : Vebjorn Berre, IBT
%
% Version no. : 1.0 SH 10.04.95 modified from rhp2xyx.m

% Called by   : many
% Calling     : none
%------------------------------------------------------------------------

function [x,y,z] = k2xyz(r,sintheta,sinphi)

  costheta = sqrt(1-sintheta.^2);
  cosphi = sqrt(1-sinphi.^2);

  x=r.*sinphi.*costheta;
  y=r.*sinphi.*sintheta;
  z=r.*cosphi;

  % detect r=Inf and r=NaN and use the convention x=0 and y=0 for
  % such cases:
  
  ind=find(isnan(r));
  if ~isempty(ind)
    x(ind) = zeros(size(ind));
    y(ind) = zeros(size(ind));
    z(ind) = Inf*ones(size(ind));
  end

  ind=find(isinf(r));
  if ~isempty(ind)
    x(ind) = zeros(size(ind));
    y(ind) = zeros(size(ind));
    z(ind) = Inf*ones(size(ind));
  end

