%------------------------------------------------------------------------
% Routine        : Lu       
%
% Description   : Bessel excitation and approximations
%		
%
% Language      : Matlab 4.1
% Written by    : Hossein Jamshidi
% 
% Version no.   : 1.0 HJG 11.9.96 First Version
%                                 Calculating width of each annular 
%                                 element which is designed to be equal
%                                 to a lobe of Zero order Bessel function.
%                 1.1  SH 17.10.96 added zero                
%                 1.2  SH 11.11.96 EqualArea is new input
%
%
% Called by	: t3usim
% Calling       : 
%------------------------------------------------------------------------
function Nn = lulu(alfa,Nn,d,EqualArea);
clear amp_ud
global amp_ud

temp=[];t=[];t1=[];amp_ud=[];amp=[];amp2=[];amp3=[];amp4=[];k=0;s=1;

radius = d/(2)*sqrt([1:Nn]/Nn);         % Equal area

%disp(' ')
%disp('Choose the Equal area or Bessel lobes ')
%disp('to replace the rings on the transducer ')
%EqualArea = input('Equal area [n/y] ? ','s');
if isempty(EqualArea)
     EqualArea  = 'n';
end

maxAmplitude =  input('Maximum amplitude of respective Bessel lobes or mean [n/y] ? ','s');
if  isempty(maxAmplitude)
     maxAmplitude = 'n';
end

rho = 0:.00001:d/2;
j0 = bessel(0,abs(rho)*alfa);

%---------- Find zeros of Bessel function ------------

ratio=(d/2)/length(j0);
i =1;
ratio=(d/2)/length(j0);
    for ii=1:length(j0)-1
    if sign(j0(ii+1)*j0(ii))<=0   
      zerose=((j0(ii)/((j0(ii)-j0(ii+1))))+ii)*ratio;
      zerosBessel(i)=zerose;
      i=i+1;
    end
 
end

%
% add end element if no zero close to it
%

if (EqualArea == 'n' & (d/2-rho(max(zerosBessel*100000))>.001))
  zerosBessel=[zerosBessel max(rho)];
end  


%----------------Choose the Equal area or Bessel lobes------------------------ 
%------------------to replace the transducer rings--------------------------

disp(' ')
disp('WAIT CALCULATING amp_ud.......')  
if EqualArea == 'y'
  zerosBessel = radius;
  rho=0:.00001:max(zerosBessel);
else 
  rho=0:.00001:max(zerosBessel);
  Nn = length(zerosBessel); % update number of elements
end

%-----------------Find maximum amplitude or minimum amplitude---------

for j=1:length(zerosBessel)
     temp=[];
     temp2=0;
  for x=k:.00001:zerosBessel(j)
    if x<=zerosBessel(j)
         temp=[temp j0(s)];
     if maxAmplitude == 'y'
         [temp2,I]=max(abs(temp));	 % max. value
         temp2=temp(I);
         temp3 = temp2 * ones(1,length(temp));
     else
         temp2 = mean(temp);
         temp3 =  temp2 * ones(1,length(temp));
     end
    end

    if s<length(rho)
       s=s+1;
    end   
  end
  k=x;
      amp2=[amp2 temp2];
      amp_ud=amp2;
      amp=[amp temp3];
      amp3=[amp3 temp];
end

%------- Plotting of Bessel function----------------------------

yyy=[-1 1];
zerosBessel=zerosBessel*1000;
for jj=1:length(zerosBessel) 
   plot([zerosBessel(jj) zerosBessel(jj)],yyy,'g')  
   axis([0 max(zerosBessel) -1 1])                       
   hold on  
   plot(rho*1000,amp3(1,1:length(rho)),'r')   % Plot of Bessel function                                  
   plot(rho*1000,amp(1,1:length(rho)),'b')    % Plot of average amplitude of corresponding lobe 
                                           % of Bessel function

end
 hold off
 xlabel('Radius [mm]')
 ylabel('Relative amplitude')
 title('Bessel excitation and approximations')
 grid

%--------------------------------------------------------------- 

amp4(1)=[ (zerosBessel(1)/2)*1000];
for jjj=2:length(zerosBessel)
   amp4=[amp4 (zerosBessel(jjj)+zerosBessel(jjj-1))/2*1000];
end
amp_ud(2,:)=amp4*1e-3;

