%------------------------------------------------------------------------
% Routine     : lusim(FILE)
% Description : Loads configuration from FILE if present, else asks for
%               file to load
%
% Language    : Matlab 4.1
% Written by  : Vebjorn Berre 12/4-93
%
% Version no. : 3.0
%             : 3.1 TKL 15.07.93 Added more choices
%             : 3.2 TKL 03.09.93 Added analysis
%             : 3.3 TKL 22.09.93 Removed analysis
%             : 3.4 FT  19.01.94 Added cnf-variables for layered medium
%             : 3.5 FT  08.02.94 Added user-defined media and pulse 
%             : 3.6 FT  20.03.94 Removed 'linjeparametre'
%             : 3.7 BJE 21.11.94 Changed text to fit smaller windows
%                                Added *.cnf filenames
%               3.8 BJE 30.11.94 Added path separator
%               3.9 SH   6.12.94 Changed call rectangular to rectangu
%               4.0 SH   7.12.94 Removed path separator from pwd call
%               4.1 LO  22.12.94 Global variable to layer modified
%               4.2 SH  19.01.95 Comment field is displayed and usr_cnfdir may be set
%               4.3 BJE 28.04.95 Removed separator test, exists already!
%                                script -> function
%               4.4 BJE 11.05.95 Changed call, safer userinterface
%               4.5 SH  16.05.95 Always update elem_pts
%               4.6 SH  28.02.96 Changed electronic/mechanical directories to 
%                		 Ultrasim examples and Site-dependent examples
%               4.7 SH  05.06.96 Added centers as in/out in lusim.m, rectangu.m
%               4.8 SH  06.09.96 Removed code for reading global variables
%               4.9 SH  17.09.96 Computes elem_pts | centers only if
%                                required
%               5.0 SH  19.09.96 Clear centers before a new file is loaded
%                                to deal with old fileformat
%
% Called by   : usimcnf, ultrasim
% Calling     : loadchek, apobserv, rectangu, annular
%------------------------------------------------------------------------

function [excitation, observasjon, media, transducer, flagg, ...
      option, x, y, z, t, elem_pts, centers, elecdelr, elecdelt, comment, ...
      pvec, plength, phase_err_ud, amp_ud, ...
      array_resp, max_resp, min_resp]= ...
    lusim(FILE,Elec,Mech,usr_cnfdir,USER_ULTRASIMHOME,separator, ...
      excitation, observasjon, media, transducer, flagg, ...
      option, x, y, z, t, elem_pts, centers, elecdelr, elecdelt, comment, ...
      pvec, plength, phase_err_ud, amp_ud, ...
      array_resp, max_resp, min_resp);
  
  
%
% get file to load if FILE is empty
%
  if isempty(FILE)
      clc
      temp=menu35('LOAD new configuration from', ...
          'Working directory','Ultrasim examples','Site-dependent examples','Your own [cnf] directory');
      
      if isempty(temp)
          temp=4;
      end
      
      if temp==1  
          cnfdir=[pwd];
        elseif temp==2 
          cnfdir=[Elec];
        elseif temp==3 
          cnfdir=[Mech];
        elseif temp==4 
          cnfdir=[usr_cnfdir];
        else
          return
      end
      
      
%
% display available files and get filename
%
      disp('  ')
      disp(['Available files in ',cnfdir])
      disp('  ')
      tmp_dir=pwd;            
      eval(['cd ',cnfdir]);
      eval(['dir *.cnf']);            % recommended extension
      eval(['dir *cnf.mat']);
      eval(['cd ',tmp_dir]);
      clear tmp_dir
      FILE = input('-> File to load [.cnf] : ','s');
      
      
%
% append '.cnf' extension if necessary
%
      if isempty(findstr(FILE,'cnf'))
          FILE=[FILE,'.cnf'];
      end
      
%
% add path and system dependent separator  
%
      FILE=[cnfdir,separator,FILE];

  end 				% get file      
  
  
%
% check if file exists, and load configuration
%
  file_ok=( exist(FILE)==2 | exist(FILE)==3 );      

  if ~file_ok 
      fprintf('\nSystem did not find :\n\n');
      disp(FILE);
      disp(' ');

  else  
      centers=[];
      disp(' ');
      disp(['Loading ',FILE]);
      disp(' '); 
      eval(['load ',FILE,' -mat']); % loads file here

%
% global variables, get rid of these in the future ?
% - check out the new if test, I think it should work
% commented out 6.9.96
%
%      global abrflagg fixeddepth pvector

%      if (~isempty(pvec) & isempty(pvector))
%          pvector=pvec;
%          pvector(1)=plength/(length(pvec)-1);
%      end
      
%      clear abrflagg fixeddepth pvector
      
%
% modify it 
%

      if flagg(3)==2
          ind = find(media(:,3)==5);
          if ~isempty(ind)
              for n = 1:length(ind)
                  eval(['global bound',int2str(media(ind(n),4))]);
                  eval(['clear bound',int2str(media(ind(n),4))]);
              end
          end
      end
      
      [excitation,observasjon,media,transducer,flagg,option]=...
          loadchek(excitation,observasjon,media,transducer,flagg,option);
      
%
% handling of comment
%
      if exist('comment')
          disp(' ');
          disp(comment);
      end
      
%
% calculate observation area
%
      [x,y,z,t]=apobserv(observasjon,option,flagg);

         if (flagg(2)==1 &( ~exist('elem_pts') | isempty(elem_pts) ...
                          |~exist ('centers')  | isempty(centers) )),
%
% compute elem_pts or centers if required for rectangular arrays
% 
             [elem_pts, centers]=rectangu(transducer,excitation,media);
          elseif flagg(2)==3
%
% elem_pts are not saved for annular arrays, therefore compute them always
%    
               elem_pts=annular(transducer, excitation, media);
          end
      
  end
  
  fprintf('\nFinished!\n');
  return
  
  
