%------------------------------------------------------------------------------
% Routine          : mills()
%
% Description      : Place elements on Mills cross
%                    Two versions:
%                    1: on x and y-axes
%                    2: on diagonals
%		     
%                    
% Output data structure:
%
% 		     el_pts(1,n) = x
% 		     el_pts(2,n) = y
% 		     el_pts(3,n) = z 
% 		     el_pts(4,n) = nn % element number in major dimension (azimuth)
% 		     el_pts(5,n) = mm % element number in minor dimension (elevation)
%
%
% Language         : Matlab syntax
% Written by       : Jan Ove Erstad
%                  : 1.0 JOE 14.03.94 Mills cross 1 & 2
%                    1.1  SH 03.06.96 Moved from rectangu.m to separate function
%
% Called by        : rectangu.m
% Routines called  : 
% Load files       :
%
%------------------------------------------------------------------------------

	function [el_pts] = mills(transducer,excitation,media);


% VEB 17/3-93

d=transducer(1);
Nn=transducer(2);
a=transducer(5);
Mm=transducer(6);
ri=transducer(9);

% SH 19.3.93:
mm = transducer(7);
nn = transducer(3);
ROC = transducer(17);
shape = transducer(18);

npts = Nn*nn*mm;   %total number of points in
		
% ---------------------------------------------------------------------
% 	JOE 14.03.1994
% 	Mills cross 1
%
if (shape == -1)
	d_az = d/Nn;
	center = fix((Nn+1)/2);
	d_el = a/Mm;
	emm = round(mm/Mm);
	
	if rem((Mm+1),2)
	disp('There has to be odd number of elements in elevation dimension');
	disp(' ');
	return
	end

	if emm > 0 
	disp(['Number of points per elevation element : ',num2str(emm),'.']);

	else
	disp('Warning!! Not enough points to fill all elements!');
	disp('Calculation is terminated!');
	return
	end 

	npts = Nn + Mm - 1; 

% allocating memory
		el_pts = zeros(5,npts);

		if (ROC == 0) | (abs(ROC) == inf),

% Planar Mills cross array
		n=0;
		el=4;
			for az = 0:Nn-1,
			x_coord = d_az*(-Nn/2 + .5 + az);
			if (x_coord ~= 0) & (az ~= (center - 1))
			n=n+1;
			el_pts(1,n) = x_coord;
			el_pts(2,n) = 0;
			el_pts(3,n) = 0;
			el_pts(4,n) = az+1;
			el_pts(5,n) = el+1;
	
			elseif  az == (center - 1)
% mid point
				for el = 0:Mm-1,
% center of elevation element
				y_coord = d_el*(-Mm/2 + .5 + el);
				n=n+1;
				el_pts(1,n) = x_coord;
				el_pts(2,n) = y_coord;
				el_pts(3,n) = 0;
				el_pts(4,n) = az +1;
				el_pts(5,n) = el+1;
				end	%for  el = 0:M
			el = 4;
			end   %if (x_coo
		
			end %for az = 0:

		else
		disp(' Curved array is not implemented !!!');
		disp(' Change ROC to 0 (zero) !!');
		return
		end	% if ROC == 0
% JOE 28.03.1994
% MILLS CROSS 2 
elseif (shape == -2)
	d_az = d/Nn;
	center = (Nn+1)/2;
	d_el = a/Mm;
	emm = round(mm/Mm);

	if emm > 0 
	disp(['Number of points per elevation element : ',num2str(emm),'.']);

	else
	disp('Warning!! Not enough points to fill all elements!');
	disp('Calculation is terminated!');
	return
	end 

	npts = Nn + Mm - 1; 

% allocating memory
		el_pts = zeros(5,npts);

		if (ROC == 0) | (abs(ROC) == inf),

% Planar Mills cross array
		n=0;
			for az=0:Nn-1,
			x_coord = d_az*(-Nn/2 + .5 + az);
			el = az;
			y_coord = d_el*(-Mm/2 + .5 + el);
			n=n+1;
			el_pts(1,n) = x_coord;
			el_pts(2,n) = y_coord;
			el_pts(3,n) = 0;
			el_pts(4,n) = az+1;
			el = el +1;
			el_pts(5,n) = el;
	
				if (x_coord ~= 0) & (az ~= (center - 1)),
				el = Mm - (az+1);
				n=n+1;
				y_coord = d_el*(-Mm/2 + .5 + el);
				el_pts(1,n) = x_coord;
				el_pts(2,n) = y_coord;
				el_pts(3,n) = 0;
				el_pts(4,n) = az+1;
				el_pts(5,n) = el+1;
				end %if x_coord ~
			end %for az=0:N
		end %if (ROC == 0) | (ab
%------------------------------------------------------------------
end
return