%------------------------------------------------------------------------
% Routine     : o3usim
%
% Description : Configuring observation-parameters PLANE/ QUASI-PLANE
%
% Language    : Matlab 4.1
% Written by  : Vebjorn Berre, IBT
%
% Version no. : 3.0 VEB 05.02.93 
%             : 3.1 TKL 30.08.93 Added dist. betw. obs. points 
%             : 3.2 TKL 24.11.93 Added yz-plane to PLANE for PE-analysis 
%             : 3.3 FT  23.02.94 Removed disp('EXIT = "x"')
%             : 3.4 FT  20.03.94 Removed 'linjeparametre'
%             : 3.5 BJE 10.10.94 Added movie option to plane and comments
%             :                  changed: fast -> coord, com1 -> com, fid, 
%             : 3.6 SH  30.11.94 Added fid=1 at end of call to o3usimtxt
%             : 3.7 SH   6.12.94 Changed o3usimtxt to o3usimtx
%             : 3.8 KE  02.05.96 Added changes for 3D observations
%	      :			 
% Called by   : usimcnf
% Calling     : o3usimtx, apobserv, menu35
%------------------------------------------------------------------------

function [observasjon,option,x,y,z,t,ind]=...
         o3usim(observasjon,option,flagg,excitation)

  
%   
% initialization
%


  if flagg(4)==1;               % rectangular coordinates
      coord=['xyzt'];
    elseif flagg(4)==3;         % spherical coordinates
      coord=['rhpt'];
  end

%  
% check if option(2) == x,y,z,t / r,h,p,t       (Defalt: x / r)
%  


  if option(2)~=coord(1) & option(2)~=coord(2) & option(2)~=coord(3) & option(2)~=coord(4)
      option(2)=coord(1);
  end

% -------------------------------
% In case of volumetric observations, option(3)= z,t / p,t (def z/p)
% Added KE 
%--------------------------------

  if option(1)=='f'
     option(3)=coord(3);
  elseif option(1)=='3' & option(3)~=coord(3) & option(3)~=coord(4)
     option(3)=coord(3);
  end




%  
% check if option(3) == x,y,z,t / r,h,p,t       (Defalt: y / h)
%

  if option(3)~=coord(1) & option(3)~=coord(2) & option(3)~=coord(3) & option(3)~=coord(4)
     option(3)=coord(2);
  end
  
%  
% option(2) and option(3) have to be different axis ...
%
  if option(2)==option(3)
      if option(2)=='y'         % y,x or 
          option(3)='x' 
        else 
          option(3)='y'         % ~y,y.
      end
  end
  
%
% choice loop
%
  com='00';
  while com(2)~='x'
      clc
      fid = 1;
      [ind]=o3usimtx(observasjon,option,flagg,excitation,coord,fid);

%      
% read number to change, put in format '01','02', ...
%
      disp('        CHANGE  = "number"')
      com = input('-> Decision (<CR> = exit): ','s');
      if isempty(com) 
          com = 'x'; 
      end
      if length(com)==1 
          com=['0',com];
      end
      if length(com)>2 
          com=['00'];
      end

%      
% # pixels along an axis
% 
      if com=='01'
          temp=input('# pixels        : ');
          if ~isempty(temp) 
              observasjon(9)=temp; 
          end  
%        
% select 1. axis
%

% Added for Volume KE 16/11

        elseif com=='02'
% ------------------------
% Cannot change this axis in case of volumetrix obs.

          if option(1)~='3' & option(1)~='f'
% ------------------------
             temp=menu35('Choose axis',coord(1),coord(2),coord(3),coord(4));
             if isempty(temp) option(2)=coord(1);
               elseif temp==1      option(2)=coord(1);
               elseif temp==2      option(2)=coord(2);
               elseif temp==3      option(2)=coord(3);
               elseif temp==4      option(2)=coord(4);
             end
             if option(2)==option(3)
                disp('WARNING: 1. and 2. axis are the same - Strike a key to continue');
                pause; 
             end
	  end
%
% set start value, 1. axis
%
        elseif com=='03'
          temp=ind(1);		% ind is initialized in o3usimt.m 
          observasjon(temp)=punkt(coord(temp),observasjon(temp),'start');
%
% set end value, 1. axis
%
        elseif com=='04'
          temp=ind(1);
          observasjon(temp+4)=punkt(coord(temp),observasjon(temp+4),'end');
% 
% select 2. axis
%
        elseif com=='05'
% ------------------------------------------
% Added for volume: can't change this axis for 3d.
% ------------------------------------------
	   if option(1)~='3' & option(1)~='f'  % 
              temp=menu35('Choose axis',coord(1),coord(2),coord(3),coord(4));
              if isempty(temp) option(3)=coord(1);
                 elseif temp==1      option(3)=coord(1);
                 elseif temp==2      option(3)=coord(2);
                 elseif temp==3      option(3)=coord(3);
                 elseif temp==4      option(3)=coord(4);
              end
              if option(2)==option(3)
                 disp('WARNING: 1. and 2. axis are the same - Strike a key to continue');
                 pause; 
              end
	   end
%
% set start value 2. axis
%
        elseif com=='06'
          temp=ind(2);
          observasjon(temp)=punkt(coord(temp),observasjon(temp),'start');
%
% set end value 2. axis
%
        elseif com=='07'
          temp=ind(2);
          observasjon(temp+4)=punkt(coord(temp),observasjon(temp+4),'end');
%
% set fixed value of 3rd or 4th dimension
%
        elseif com=='08' | com=='09'
          temp=ind(str2num(com(2))-5);	
          observasjon(temp)=punkt(coord(temp),observasjon(temp),'fixed');
          observasjon(temp+4)=observasjon(temp);
%
% set start_t, stop_t if movie
%
% ------------------------
% When checked for option(1)=='m', check also for 'f'
% ------------------------
        elseif com=='10' & (option(1)=='m' | option(1)=='f')
	  observasjon(4)=punkt('t',0,'start');		% default: 0
% ------------------------
% When checked for option(1)=='m', check also for 'f'
% ------------------------
	elseif com=='11' & (option(1)=='m' | option(1)=='f')
	  observasjon(8)=punkt('t',5*1e-6,'end');	% default: 5 us

% ---------------------------------------
% Added for Volume KE 16/11
%
%
% Select 3. axis.. Either z or t, and only in Volume
%
% ---------------------------------------
	elseif com=='12' 
	   if option(1)=='3' | option(1)=='f'
	     temp=menu35('Choose axis',coord(3),coord(4));
	     if temp==2
		option(3)=coord(4);
	     else
	 	option(3)=coord(3)
	     end
	   end

% set start value 3. axis
%
        elseif com=='13'
          temp=ind(3);
          observasjon(temp)=punkt(coord(temp),observasjon(temp),'start');
%
% set end value 3. axis
%
        elseif com=='14'
          temp=ind(3);
          observasjon(temp+4)=punkt(coord(temp),observasjon(temp+4),'end');


% ----------Added until here -----------------

%
% # obs point/mm
%
        elseif com=='15'
          temp=input('Number of observation-points/mm  : ');
          if ~isempty(temp) 
              observasjon(15)=temp; 
          end 
      end       % change of parameters
      
  end           %while

  [x,y,z,t]=apobserv(observasjon,option,flagg);
  
  
  
  
