%------------------------------------------------------------------------
% Routine         : t1usim       
%
% Description     : Configuring transducer-parameters
%			1 1/2D CURVED RECTANGULAR ARRAY
%
% Language        : Matlab 4.1
% Written by      : Vebjorn Berre, IBT
%
% Version no.     : 1.0 VEB 27.10.92 First Version
%                 : 2.0 SH  30.03.93
%                   3.0 FT  23.02.94 Removed disp('EXIT = "x"')
%                   3.1 FT  20.03.94 kerf->comments + check if choise is
%                                    legal
%                   3.2 SH   6.12.94 Changed calls: rectangular to rectangu
%                                                   t1usimtxt   to t1usimtx
%                   3.3 SH   9. 1.95 Added input of curved array parameters
%                 : 3.4 KE   2.05.96 '??' at transducer type gives a list of
%                                    options (i.e. transducer types)
%                   3.5 SH   8. 5.96 Slight modification of user interface
%                   3.6 SH  21.05.96 Changed test of input for xdcr shape
%                   3.7 SH  03.06.96 centers as output
%                   3.8 SH  15.07.96 split transducer(10:16) to t1us15d.m
%                   3.9 SH  22.05.97 Toggling of mm/lambda in transducer menu 
%
% Called by       : usimcnf
% Routines called : rectangu, t1usimtx, t1us15d
%------------------------------------------------------------------------

function [transducer,elem_pts,centers]=t1usim(transducer,flagg,excitation,media)

fid=1;
lambda=media(1,2)/excitation(1);
if length(flagg)>4
  if flagg(5)==1
    lambda_local=1;
  elseif flagg(5)==2
    lambda_local=media(1,2)/excitation(1)*1e3;
  end
else
  lambda_local=1;
end

tmp=size(transducer);
if tmp(2)<18 
  tmp=transducer;
  transducer=zeros([1,18]);
  transducer([1:1:length(tmp)])=tmp;
end

com1=0;
while com1~='x'
  clc

  t1usimtx;
  
  disp('	CHANGE 		= "number"')
  com1 = input('-> Decision (<CR> = exit): ','s');
  if isempty(com1) com1 = 'x'; end
  if length(com1)==1 com1=['0',com1];end
  if length(com1)>2
    com1 = '99'
  end
  
  curved = transducer(17) ~= 0 & finite(transducer(17));  
  if com1=='01'
    if curved
        temp=input('Azimuth array-aperture (chord)	d (a) = ');
    else
        temp=input('Azimuth array-aperture 		d (a) = ');
    end
    if ~isempty(temp) transducer(1)=temp*lambda_local*1e-3; end
  elseif com1=='00'
%
% toggle mm/lambda flag (flagg(5) 1=mm, 2=lambda)
%
    flagg(5) = rem(flagg(5)+1,2);
    if (flagg(5) == 0), flagg(5) = 2; end
    if flagg(5)==1
       lambda_local=1;
    elseif flagg(5)==2
       lambda_local=media(1,2)/excitation(1)*1e3;
    end
  elseif com1=='28' & curved
    temp=input('Azimuth arc-length                     = ');
    if ~isempty(temp)
       arc = temp*lambda_local*1e-3;
       ROC = abs(transducer(17));
       transducer(1)=2*ROC*sin(arc/(2*ROC));  
    end
  elseif com1=='29' & curved
    temp=input('Azimuth angle                          = ');
    if ~isempty(temp)
       ROC = abs(transducer(17));     
       transducer(1) = 2*ROC*sin(pi*temp/(360));
    end
  elseif com1=='02'
    temp=input('Azimuth # elements		Nn (P) = ');
    if ~isempty(temp) transducer(2)=temp; end
  elseif com1=='03'
    temp=input('Azimuth # points		R = ');
    if ~isempty(temp) transducer(3)=temp; end
%  elseif com1=='04'
%    temp=input('Azimuth kerf [microns]		ak = ');
%    if ~isempty(temp) transducer(4)=temp*1e-6; end
  elseif com1=='05'
    if transducer(6)==3 
      disp(' Not allowed to change this parameter!');
      disp(' Change ''ai'' or ''ao'' to change total aperture!');
      disp(' Press any key to continue...');
      pause;
    elseif transducer(6)==5
      disp(' Not allowed to change this parameter!');
      disp(' Change ''ai'', ''am'' or ''ao'' to change total aperture!');
      disp(' Press any key to continue...');
      pause;
    else
      temp=input('Elevation array-aperture 	a = ');
      if ~isempty(temp) 
	transducer(5)=temp*lambda_local*1e-3; 
	transducer(12)=transducer(5);
      end
    end
  elseif com1=='06'
    temp=input('Elevation # elements		Mm (Q) = ');
    if ~isempty(temp) transducer(6)=temp; 
      if temp~=5 transducer(14)=0; end
      if temp~=3 & temp~=5 transducer(13)=0;end
      transducer(5)=2*transducer(14)+transducer(12)+2*transducer(13);
    end
  elseif com1=='07'
    temp=input('Elevation # points			S = ');
    if ~isempty(temp) transducer(7)=temp; end
%  elseif com1=='08'
%    temp=input('Elevation kerf [microns]		bk = ');
%    if ~isempty(temp) transducer(8)=temp*1e-6; end
  elseif com1=='09'
    temp=input('Elevation fixed focus  		ri (F) = ');
    if ~isempty(temp) transducer(9)=temp*lambda_local*1e-3; end
  elseif (com1=='10'|com1=='11'|com1=='12'|com1=='13'|com1=='14'| ...
    com1=='15'|com1=='16') & (transducer(6)==3 | transducer(6)==5),
    transducer=t1us15d(com1,lambda_local,transducer);
  elseif com1=='17'
    temp=input('Azimuth Fixed focus (Radius of curvature)   ROC 	= ');
    if ~isempty(temp) transducer(17)=temp*lambda_local*1e-3; end
  elseif com1=='18'
% ---------------------------------------------
% Added a help procedure... Enter ? and you'll get a list of possible trans.
% KE 
    temp=input('Transducer shape (? - help): ','s');
    if ~isempty(temp)
%
% changed test in while, SH 21.05.96 - otherwise 2.5 etc would not work
% 
       while strcmp(temp,'?') 
	  fprintf('     0  : Rectangular Transducer\n');
	  fprintf('     2  : Elliptical Transducer\n');
	  fprintf('     2.5: Superelliptical Transducer\n');
	  fprintf('     All values >= 0  are allowed\n');
	  fprintf('    -8  : Octagonal Transducer\n');
	  fprintf('    -2  : Mills Cross Type II\n');
	  fprintf('    -1  : Mills Cross Type I\n');
	  temp=input('Transducer shape  : ','s');
       end
       if ~isempty(str2num(temp))
          transducer(18)=str2num(temp);   
       end     
    end
  end
end 					%while

%elem_pts=initelem(transducer,flagg(2));

[elem_pts, centers] = rectangu(transducer,excitation,media);
elem_pts=real(elem_pts);









