%------------------------------------------------------------------------
% Routine   	: t3usimtx
%
% Description   : Configuring transducer-parameters - txt-file
%				ANNULAR ARRAY
%
% Language      : Matlab 4.1
% Written by	: Vebjorn Berre, IBT
%
% Version no.   : 3.0 VEB 27.10.92
% Version no.   : 3.1 FT  27.09.93 Changed output format for trans.type
% Version no.   : 3.2 TKL 29.10.93 Replaced the lambda_local printout
%               : 3.3 FT  09.02.93 Parameters displayed depend on flagg(3)
%               : 3.4 SH   6.12.94 Shortened from t3usimtxt to t3usimtx
%               : 3.5 HJG 29.01.96 Scaling factor is printed out by printf 
%                                  function on line 44.
%                 3.6 SH  09.10.96 Added transducer in call to transtxt
%                                  added if for check in printout of
%                                  transducer(12) which is changed to tr..(13)
%                 3.7 SH  11.11.96 Output of transdcuer(12:14) for Bessel beam
%                 3.8 SH  25.03.97 Conical transducer
%%                            

% Called by     : t3usim
% Calling	: transtxt
%------------------------------------------------------------------------

 
fprintf(fid,'\t\t-------      TRANSDUCER SUBMENU      --------- \n');
fprintf(fid,'\t\t-------        ANNULAR  ARRAY        --------- \n');
  if length(flagg) > 4
    if flagg(5)==1 
      fprintf(fid,['\t\t\t    Input is in [mm] units \n']);
      fprintf(fid,['\t\t\t       lambda = ',num2str(lambda*1e3),' mm \n']);
    elseif flagg(5)==2 
      fprintf(fid,['\t\t\t    Input is in [lambda] units \n']);
      fprintf(fid,['\t\t\t       lambda = ',num2str(lambda*1e3),' mm \n']);
    end
  else
      fprintf(fid,['\t\t\t    Input is in [mm] units \n']);
      fprintf(fid,['\t\t\t       lambda = ',num2str(lambda*1e3),' mm \n']);
  end
%fprintf(fid,['\t\t\t    (lambda_local = ',num2str(lambda_local),' mm )\n']);
fprintf(fid,'\n');

transtyp = transtxt(transducer(18),transducer);
fprintf(fid,['18) Transducer type \t\t : ',transtyp]);
fprintf(fid,'\n')
fprintf(fid,'\n');

if (transducer(18)>3 & transducer(18) <=9),
  fprintf(fid,['12) Bessel beam order \t n \t = ', ...
    num2str(transducer(12)),'\n']); 
  fprintf(fid,['13) Scaling factor \t alpha \t = ', ...
    num2str(transducer(13)),' m^-1 \n']); 
  fprintf(fid,['14) Rotation angle\t\t = ', ...
    num2str(transducer(14)),' degrees \n']);
  fprintf(fid,'\n'); 			%19-1-96
end
if (transducer(18)==10)
  fprintf(fid,['12) Axicon angle \t alpha \t =    ', ...
    num2str((180/pi)*transducer(12)),' degrees \n']);
      if (transducer(12)~=0)
	tgfi = tan(transducer(12));
%
% modified to simpler expression 25.3.97:
% was cos(excitation(4))*(tgfi+1/tgfi)
%
	dof = 500*transducer(1)*cos(excitation(4))/tgfi;
      else
	dof = Inf;
      end
      fprintf(fid,'    Estimated depth of field \t = %7.2f [mm]\n',dof);
end
if (transducer(18) ~= 10) % for all but conical
  fprintf(fid,'9) Fixed focus \t F \t\t = %7.2f mm = %7.2f lambda \n', ...
      transducer(9)*1e3,transducer(9)/lambda);
end
fprintf(fid,'1) Transducer aperture \t D \t = %7.2f mm = %7.2f lambda \n',transducer(1)*1e3,transducer(1)/lambda);
fprintf(fid,'2) # elements \t\t N  \t = %4.0f \n',transducer(2));
if flagg(3)~=2  
  fprintf(fid,'3) # points   \t\t P  \t = %4.0f \n',transducer(3));
else
  fprintf(fid,'3) # rays   \t\t P  \t = %4.0f \n',transducer(3));
  fprintf(fid,'10) Rotation angle \t theta \t = %7.2f deg \n',...
      transducer(10)*180/pi);
  fprintf(fid,'15) Transducer offset \t tr_off\t = %7.2f mm \n',...
      transducer(15)*1e3);
end 
 
fprintf(fid,'\n');






