% -----------------------------------------------------------------------------
% Function     : config = usimcnf(ACTION,flagg,option,num);
% Description  : Controls the GUI of the CONFIG - CALCULATION window,
%                depending on the ACTION parameter.
%
% In:  ACTION    'initialize'        initialize config window, equals the old 
%                                    usimcnf-file. 
%
%                'update_allflags'   update menus that are flag dependent.
%                                    usually sets 'enable' and 'checked' on/off
%
%                'update_****flags'  update ONLY flaggroup **** and dependencies
%
%                'update_calcresp'   update submenus that need a response calculation
%
%                'update_colormap'   update colormap checking   
%
%                'update_shading'    update shading checking
%
%                                                             -BJE 22.04.95
%
% Language    : Matlab 4.0
% Written by  : Vebjorn Berre ,IBT
%
% Version no. : 1.0 VEB 04.12.92 
%               1.1 VEB 07.01.93 
%               2.0 VEB 09.03.93 
%               2.1 VEB 31.03.93 
%               2.2 SH  18.05.93 
%               3.0 FT  23.08.93
%               3.1 TKL 03.09.93 Added ANALYSIS in Configuration 
%               3.2 TKL 14.09.93 Added subentries in PE
%               3.2 TKL 15.09.93 Removed close screen, added Clear Screen
%               3.3 TKL 17.09.93 Changed PE-calls
%               3.4 TKL 03.09.93 Removed ANALYSIS from Configuration 
%               3.5 FT  02.09.93 New menu option 'Integrate Sidelobe Energy'
%               3.6 FT  27.09.93 New menu option 'SetFlag Medium 3D Layered'
%               3.7 SH  19.11.93 New menu option for PE: Iso beamwidth
%               3.8 TKL 22.11.93 Added usr_resdir to PE-file calls,
%                                changed to 'short' filenames for pe 
%               3.9  SH  3.12.93 Added flagg in call of peplot and peplcont
%               3.10 SH 22.12.93 Added choice of color and shading in menu
%                                reorganized calculate and optimize menus
%               4.0 FT  01.06.94 Added transducer in call to eusim
%               4.1 FT  19.01.94 Corrected 'list to file'-Callback
%               4.2 FT  26.01.94 Removed submenus to view/media and calc/layers
%               4.3 FT  15.02.94 Changed som Callbacks
%               4.4 JOE 25.01.94 Added COARRAY in Calculations
%               4.5 FT  28.02.94 Added layerflag
%               4.6 FT  20.03.94 Removed some obs.options Added call to chmedia
%               4.7 JOE 28.03.94 Added routine for array thinning in Coarray
%               4.8 JOE 22.04.94 Added vector for Error-coarray in cocomp/-plot
%               4.9 JOE 20.05.94 Included media and excitation in coplot
%               5.0 FT  24.05.94 Changed Callback to view excitation
%               5.1 JOE 16.08.94 Enabled direct call for optional Coarray plots
%               5.2 SH  02.09.94 Moved Quit submenus to File menu to save space
%               5.3 FT  29.09.94 Changed Callback Configuration-Medium
%               5.4 BJE 06.10.94 Added movie option for PE      
%               5.5 JOE 19.10.94 Coarray menu simplified+ added optimizing call
%               5.6 BJE 18.11.94 Added max_resp, min_resp in PE (2D Response)
%               5.7 SH  23.11.94 Moved Coarray menu items, changed menubar
%                                option (for PC compatibility)
%               5.8 SH  30.11.94 Corrected call for listing of parameters to file
%               5.9 SH   1.12.94 Minor correction of listing of parameters
%               6.0 SH   3. 1.95 Added transducer in call of vwtrans and busim
%               6.1 SH  14.02.95 Added comment in call to listusim
%               6.2 SH  16.03.95 Simplified Label of rectangular menu
%               6.3 LO  31.03.95 Added elecdelt,elecdelr in call to listusim if flagg(1)==2
%                                Configuration to printer is also included
%               6.4 HGJ 02.04.95 Color-encoded plot from 2D response
%               6.5 SH  10.04.95 flagg(4)=4 <=> sin(theta) as axis
%               6.6 BJE 20.04.95 Reorganized file, script -> function , smoother GUI
%                                Added checking on flags and their dependencies.
%               6.7 BJE 26.04.95 Changed callback to function in Configuration - list ++
%               6.8 BJE 11.05.95 Do not set colormap or shading in 'initialize', changed lusim call
%               6.9 SH  16.05.95 Removed View-transducer-points menu item
%               7.0 BJE 22.05.95 Changed call to msl
%               7.1 SH  30.05.95 Changed call to msl, moved View apodization menu
%               7.2 BJE 22.06.95 Changed call from msl to mslmain
%               7.3 SH  27.10.95 Added second routine for thinning
%               7.4 BJE 02.11.95 Added array response calculation in calculation
%               7.5 BJE 23.11.95 Added Weighting and thinning
%               7.6 BJE 27.11.95 Added Restore all
%               7.7 SH  27.03.96 Added Help function, + changed sin(phi) -> wavenumber
%               7.8 KE   2.05.96 Added response calculation for 3D observations
%               7.9 SH  15.05.96 Changed label for far-field calculation
%                                Removed change directory feature (did not work)
%                                changed addresses for h_list
%               8.0 SH  20.05.96 Added 'config' in call to vwtrans
%                                Made 'comment' an output of susim
%               8.1 SH  04.06.96 centers output from t1usim, t3usim, lusim 
%                                centers input to thin, pecomp, bporg, lusim
%                                Merged menu 'Clear' and 'Subplot' to 'Screen'
%               8.2 SH  17.07.96 Added Analyze Curved/Linear Arrays
%                                corrected addressing of handles
%               8.3 SH  04.09.96 Enabled contour plot for movie, added two
%                                parameters in call to peplcont
%               8.4 SH  16.09.96 Added centers to input of susim
%		8.5 NAA 23.10.96 Provisons for sub aperture imaging
%               8.6 SH  18.11.96 Moved optimization choices for transducer
%                                to separate routine
%               8.7 SH  03.01.97 centers sent to routine ffmain
%               8.8 KE/SH 20.1.97 variable visualize sent to peplot3d
%               8.9 SH  11.07.97 added usr_resdir, separator to thin
%               9.0 SH   6.04.98 Added centers in call of thinning()
%                                
%                               
% Called by   : ultrasim, setcomap, setshade
% Calling     : eusim, tusim, ousim, susim, lusim, nusim, dusim,
%               cleanscr, pecomp, peplot, peplcont, coartool, optiwate, thinning
%               vwtrans, setcomap, setshade, mslmain, listusim, usimcnf, ffmain
% -----------------------------------------------------------------------------
  

function config=usimcnf(ACTION,flagg,option,num);
    
  
% ********************************************************
%
%                       ACTION 'initialize'
%
% ********************************************************
  
  if strcmp(ACTION,'initialize')
      config=figure('Name','ULTRASIM - CONFIGURATION - CALCULATION',...
	  'Numbertitle','off',...
	  'Units','normalized','Position',[0.5,0.07,0.5,0.4],...
	  'Menubar','none','Visible','off','Backingstore','off');
      
%
% MENUBAR: File
%
      tmpobj=uimenu(config,'Label','File');

      uimenu(tmpobj,'Label','Load Configuration','Callback', ...
	  ['[excitation, observasjon, media, transducer, flagg, option,', ...
	  'x,y,z,t, elem_pts, centers, elecdelr, elecdelt, comment,', ...
	  'pvec, plength, phase_err_ud, amp_ud,', ...
	  'array_resp, max_resp, min_resp] = ', ...
	  'lusim([],Elec,Mech,usr_cnfdir,USER_ULTRASIMHOME,separator,', ...
	  'excitation, observasjon, media, transducer, flagg, option,', ...
	  'x,y,z,t, elem_pts, centers, elecdelr, elecdelt, comment,', ...
	  'pvec, plength, phase_err_ud, amp_ud,', ...
	    'array_resp, max_resp, min_resp);',...
	  'usimcnf(''update_allflags'',flagg,option);']);

      uimenu(tmpobj,'Label','Save Configuration','Callback',...
	  ['[comment]=susim([], excitation, observasjon, media,' ...
	  'transducer, flagg,', ...
	  'option, x, y, z, t, elem_pts, elecdelr, elecdelt, comment,', ...
	  'pvec, plength, phase_err_ud, amp_ud,', ...
	  'array_resp, max_resp, min_resp,', ...
	  'Elec, Mech, usr_cnfdir, USER_ULTRASIMHOME, separator,centers);']);


%      uimenu(tmpobj,'Label','Change cnf-directory','Separator','on',...
%          'Callback','cdusim');
      uimenu(tmpobj,'Label','Quit ULTRASIM','Separator','on',...
	  'Callback',['qqq=0;usimquit']);
      uimenu(tmpobj,'Label','Quit MATLAB','Callback',['qqq=1;usimquit']);
	    
      
%
% MENUBAR: SetFlags
%
      tmpobj=uimenu(config,'Label','SetFlags');
      
%
%               'Focus-mode'
%      
      tmpobj1=uimenu(tmpobj,'Label','Focus-mode');
      h_flagfmod(1)=uimenu(tmpobj1,'Label','Fixed focus','Callback',...
	  'flagg(1)=1;usimcnf(''update_fmodflags'',flagg,option);');
      h_flagfmod(2)=uimenu(tmpobj1,'Label','Dynamic focus, steered response',...
	  'Callback','flagg(1)=2;usimcnf(''update_fmodflags'',flagg,option);');
      h_flagfmod(3)=uimenu(tmpobj1,'Label','Sub aperture focusing',...
	  'Callback','flagg(1)=3;usimcnf(''update_fmodflags'',flagg,option);');
      
%
%               'TransducerGeometry'
%      
      tmpobj1=uimenu(tmpobj,'Label','TransducerGeometry');
      h_flagtgeo(1)=uimenu(tmpobj1,'Label','Rectangular and Curved Array',...
	  'Callback','flagg(2)=1;usimcnf(''update_tgeoflags'',flagg,option);');
      h_flagtgeo(2)=uimenu(tmpobj1,'Label','Annular Array',...
	  'Callback','flagg(2)=3;usimcnf(''update_tgeoflags'',flagg,option);');
      
%
%               'Medium'
%      
      tmpobj1=uimenu(tmpobj,'Label','Medium');
      h_flagmedi(1)=uimenu(tmpobj1,'Label','Homogeneous','Callback','flagg(3)=1;');
      h_flagmedi(2)=uimenu(tmpobj1,'Label','Layered 2D','Callback',...
	  ['[flagg,media] = chmedia(flagg,media,transducer,2);',...
	  'usimcnf(''update_mediflags'',flagg,option);']);
      h_flagmedi(3)=uimenu(tmpobj1,'Label','Layered 3D','Callback',...
	  ['[flagg,media] = chmedia(flagg,media,transducer,3);',...
	  'usimcnf(''update_mediflags'',flagg,option);']);
      
%
%               'Coordinates'
%      
      tmpobj1=uimenu(tmpobj,'Label','Coordinates');
      h_flagcoor(1)=uimenu(tmpobj1,'Label','Rectangular',...
	  'Callback','flagg(4)=1;usimcnf(''update_coorflags'',flagg,option);');
      h_flagcoor(2)=uimenu(tmpobj1,'Label','Cylindrical',...
	  'Callback','flagg(4)=2;','enable','off');
      h_flagcoor(3)=uimenu(tmpobj1,'Label','Spherical',...
	  'Callback','flagg(4)=3;usimcnf(''update_coorflags'',flagg,option);');
%
% changed label 27.03.96 SH
%
      h_flagcoor(4)=uimenu(tmpobj1,'Label','k-space (sin(angle))',...
	  'Callback','flagg(4)=4;usimcnf(''update_coorflags'',flagg,option);');

%
%               'mm/lambda'
%      
      tmpobj1=uimenu(tmpobj,'Label','mm/lambda');
      h_flagmmlambda(1)=uimenu(tmpobj1,'Label','[mm]','Callback',...
	  'flagg(5)=1;usimcnf(''update_mmlambdaflags'',flagg,option);');
      h_flagmmlambda(2)=uimenu(tmpobj1,'Label','[lambda]','Callback',...
	  'flagg(5)=2;usimcnf(''update_mmlambdaflags'',flagg,option);');
      
%
%               'Observation'
%
      tmpobj1=uimenu(tmpobj,'Label','Observation');
      h_flagobsv(1)=uimenu(tmpobj1,'Label','Point','Callback',...
	  ['option(1)=''p'';usimcnf(''update_obsvflags'',flagg,option);']);
      h_flagobsv(2)=uimenu(tmpobj1,'Label','Line','Callback',...
	  ['option(1)=''1'';usimcnf(''update_obsvflags'',flagg,option);']);
      h_flagobsv(3)=uimenu(tmpobj1,'Label','Plane','Callback',...
	  ['option(1)=''2'';usimcnf(''update_obsvflags'',flagg,option);']);
      h_flagobsv(4)=uimenu(tmpobj1,'Label','Plane > Movie','Callback',...
	  ['option(1)=''m'';usimcnf(''update_obsvflags'',flagg,option);']);
% ---------------------------------------------------
% Added volume KE 16/11
      h_flag3Dobsv(1)=uimenu(tmpobj1,'Label','Volume','Callback',...
	  ['option(1)=''3'';usimcnf(''update_obsvflags'',flagg,option);']);
      h_flag3Dobsv(2)=uimenu(tmpobj1,'Label','Volume > Movie','Callback',...
	  ['option(1)=''f'';usimcnf(''update_obsvflags'',flagg,option);']);
% ---------------------------------------------------


%
% MENUBAR: 'Configuration'
%
      tmpobj=uimenu(config,'Label','Configuration');

%
%               'Excitation'
%      
      tmpobj2=uimenu(tmpobj,'Label','Excitation','Callback',...
	  '[excitation,pvec,plength]=eusim(excitation,flagg,transducer);');
	    
%
%               'Transducer'
%      
      tmpobj2=uimenu(tmpobj,'Label','Transducer');          
      uimenu(tmpobj2,'Label','Setup','Callback',...
	  ['if flagg(2)==1,',...
	  '[transducer,elem_pts,centers]=t1usim(transducer,flagg,excitation,media);',...
	  'elseif flagg(2)==3,',...
	  '[transducer,elem_pts,centers]=t3usim(transducer,flagg,excitation,media);',...
	  'end']);
      h_configtrans(1)=uimenu(tmpobj2,'Label','Thinning','Separator','on','Callback',...
	  ['[elem_pts,centers]=thin(transducer,flagg,elem_pts,centers,config, usr_resdir,separator);']);
      
%      uimenu(tmpobj2,'Label','Restore all', ...
%	  'Callback','[elem_pts] = restore(elem_pts);');

      h_configtrans(2)=uimenu(tmpobj2,'Label','Optimization','Callback',...
	  ['[elem_pts, centers, weights, u0, u1] =',...
	    'thinmain(elem_pts,centers,flagg,media,',...
	    'excitation,transducer,config,plotfig,', ... 
	    'usr_resdir,separator,ULTRASIMHOME);']);
      h_configtrans(3) = h_configtrans(2);
%      h_configtrans(3)=uimenu(tmpobj2,'Label','Weight and Thin (CPLEX)','Callback',...
%	  ['[elem_pts]=wntmain(elem_pts, flagg, media, excitation, transducer,', ...
%	  'config, plotfig, usr_resdir, separator, ULTRASIMHOME);']); 
   
      h_configtrans(4)=uimenu(tmpobj2,'Label','Perturbe & thin','Separator','on','Callback',...
	  ['[centers,elem_pts]=thinning(transducer,flagg,elem_pts,centers,config);']);
      h_configtrans(5)=uimenu(tmpobj2,'Label','Weighting (Remez)','Callback', ...
	  ['optiwate(elem_pts,transducer,option,media,excitation,flagg,config);']);

%
%               'Beamforming'
%      
      tmpobj2=uimenu(tmpobj,'Label','Beamforming','Callback',...
	  ['if flagg(1)==1,',... 
	  '[excitation]=busim(excitation,flagg,transducer);',...
	  'elseif flagg(1)==2',...
	  '[excitation,elecdelr,elecdelt] = ',...
	  'bdynusim(excitation,transducer,elecdelr,elecdelt,flagg);',...
	  'elseif flagg(1)==3',...
	  '[excitation] = ',...
	  'busim(excitation,flagg,transducer);',...
	  'end;']);
      
%
%               'Medium'
%      
      tmpobj2=uimenu(tmpobj,'Label','Medium','Callback',...
	  '[media,flagg] = musim(media,transducer,excitation,flagg);');
      
%
%               'Observation'
%      
      tmpobj2=uimenu(tmpobj,'Label','Observation','Callback',...
	  '[observasjon,option,x,y,z,t]=ousim(observasjon,option,flagg,excitation);'); 
      
%
%               'List'
%
      tmpobj2=uimenu(tmpobj,'Label','List','Separator','on');
      uimenu(tmpobj2,'Label','List to screen','Callback', ...
	  ['listusim(''screen'',excitation,media,observasjon,transducer,', ...
	  'option,flagg,comment,elecdelt,elecdelr,separator);']);
      uimenu(tmpobj2,'Label','List to file','Callback', ...
	  ['listusim(''file'',excitation,media,observasjon,transducer,', ...
	  'option,flagg,comment,elecdelt,elecdelr,separator);']);
      uimenu(tmpobj2,'Label','List to printer','Callback', ...
	  ['listusim(''printer'',excitation,media,observasjon,transducer,', ...
	  'option,flagg,comment,elecdelt,elecdelr,separator,printercmd);']);


%
% MENUBAR: 'View'
%
      tmpobj=uimenu(config,'Label','View');
      
%
%               'Excitation - transmitted signal'
%
      uimenu(tmpobj,'Label','Excitation',...
	  'Callback',...
	  ['if ~excitation(13),'...
	  'vwexci(excitation,flagg);'...
	  'else,'...
	  'vwexci(excitation,flagg,pvec,plength);'...
	  'end']);
      
%
%               'Spectrum with depth'
%
      uimenu(tmpobj,'Label','Spectrum with depth',...
	  'Callback','vwdepth(excitation,media);');
      
%
%               'Observation'
%
      uimenu(tmpobj,'Label','Observation',...
	  'Callback','viewobsv(observasjon,x,y,z,t,option);');
      
      tmpobj2=uimenu(tmpobj,'Label','Media','Callback',...
	  ['viewprob(x,z,media,excitation,transducer,flagg,',...
	  'observasjon,config,option);']);
      
%
%               'Transducer'
%
      tmpobj2=uimenu(tmpobj,'Label','Transducer');
%      uimenu(tmpobj2,'Label','Points',...
%          'Callback','viewtran(elem_pts);');
      uimenu(tmpobj2,'Label','2D-plots ',...
	  'Callback','viewtrsd(transducer,elem_pts,flagg);');
      uimenu(tmpobj2,'Label','Surface','Callback',...
	  'vwtrans(elem_pts,flagg,transducer,config);');
%
%               'Apodization/Weighting'
%      
      
      tmpobj2=uimenu(tmpobj,'Label','Apodization',...
	  'Callback','vwapod(transducer,excitation,elem_pts,flagg);');
      
%
%               'Delay'
%
      tmpobj2=uimenu(tmpobj,'Label','Delay');
      uimenu(tmpobj2,'Label','Phase-centers',...
	  'Callback','vwdelay(transducer,excitation,media,elem_pts,centers,flagg,3);');
      uimenu(tmpobj2,'Label','Exact delays',...
	  'Callback','vwdelay(transducer,excitation,media,elem_pts,centers,flagg,1);');
      uimenu(tmpobj2,'Label','Quantization Error',...
	  'Callback','vwdelay(transducer,excitation,media,elem_pts,centers,flagg,2);');
      
      
%
% MENUBAR: 'Calculations'
%
      tmpobj=uimenu(config,'Label','Calculations');
      
%
%               'Layers'
%
      h_calclayer=uimenu(tmpobj,'Label','Layers','Callback',...
	  ['method = ''layers'';layers(x,z,media,excitation,',...
	  'transducer,flagg,observasjon,plotfig,option,elecdelt,elecdelr)']);
      
%
%               'Beam-Pattern'
%
      h_calcbp = uimenu(tmpobj,'Label','Beam-Pattern');
      uimenu(h_calcbp,'Label','Peak Calculation','Callback',...
	  ['method = ''peak'';',...
	  'if excitation(13)==0,',...
	  'array_resp=bporg(excitation,transducer,media,observasjon,',...
	  'flagg,x,y,z,t,elem_pts,centers,plotfig,config,option,0);',...
	  'else ',...
	  'array_resp=bporg(excitation,transducer,media,observasjon,',...
	  'flagg,x,y,z,t,elem_pts,centers,plotfig,config,option,0,pvec,plength);',...
	  'end;']);
      uimenu(h_calcbp,'Label','Energy Calculation','Callback',...
	  ['method = ''energy'';',...
	  'if excitation(13)==0,',...
	  '[array_resp,energy]=bporg(excitation,transducer,media,',...
	  'observasjon,flagg,x,y,z,t,elem_pts,centers,plotfig,config,option,1);',...
	  'else ',...
	  '[array_resp,energy]=bporg(excitation,transducer,media,observasjon',...
	  ',flagg,x,y,z,t,elem_pts,centers,plotfig,config,option,1,pvec,plength);',...
	  'end;']);
      uimenu(h_calcbp,'Label','Integrate Sidelobe Energy','Callback',...
	  ['if exist(''energy'')==1,',...
	  '[angle,ienergy]=intenerg(plotfig,excitation,observasjon,',...
	  'energy,option,flagg);',...
	  'else disp(''Variable energy must be defined''); end;'])
      





%
%               '2D Response'
%
      h_calc2D = uimenu(tmpobj,'Label','2D Response');
      
      uimenu(h_calc2D,'Label','Compute response','Callback', ...
	  ['method = ''2DResponse'';'...
	  '[array_resp,max_resp,min_resp] = pecomp(excitation,transducer,',...
	  'media,observasjon,option,flagg,x,y,z,t,elem_pts,centers,config,',...
	  'plotfig,usr_resdir);',...
	  'usimcnf(''update_calcresp'',flagg,option);']);
      
      h_calcresp(1) = uimenu(h_calc2D,'Label','Surface plot',...
	  'enable','off','Callback', ...
	  ['peplot(array_resp,max_resp,min_resp,excitation,transducer,media,'...
	  'observasjon,option,flagg,x,y,z,t,config,',...
	  'plotfig,plotfigOrigHandle,usr_resdir)']);
      
      h_calcresp(2) = uimenu(h_calc2D,'Label','Surface movie','enable','off','Callback', ...
	  ['peplot(array_resp,max_resp,min_resp,excitation,transducer,media,'...
	  'observasjon,option,flagg,x,y,z,t,config,',...
	  'plotfig, plotfigOrigHandle,usr_resdir)']);
      
      h_calcresp(3) = uimenu(h_calc2D,'Label','Contour plot',...
	  'enable','off','Callback', ...
	  ['peplcont(array_resp,excitation,media,transducer,option,flagg,',...
	  'x,y,z,t,plotfig,plotfigOrigHandle,usr_resdir,observasjon, separator);']);
      
      h_calcresp(4) = uimenu(h_calc2D,'Label','Color-encoded','enable','off','Callback', ...
	  ['imageplo(array_resp,excitation,media,transducer,option,flagg,',...
	  'x,y,z,t,plotfig,plotfigOrigHandle);']);

% -------------------------------------------------
% Added for 3D KE 24/1/96
      h_calc3dresp(1) = uimenu(h_calc2D,'Label','Slice plot','enable','off','Callback', ...
	  ['peplot3d(array_resp, max_resp, min_resp, excitation, transducer, media,', ...
	  'observasjon, option, flagg, x,y,z,t, config, visualize,', ...
	  'plotfig, plotfigOrigHandle, usr_resdir);']); 

      h_calc3dresp(2) = uimenu(h_calc2D,'Label','Slice movie','enable','off','Callback', ...
	  ['peplot3d(array_resp, max_resp, min_resp, excitation, transducer, media,', ...
	  'observasjon, option, flagg, x,y,z,t, config, visualize,', ...
	  'plotfig, plotfigOrigHandle, usr_resdir);']);

% ------------------------------------------------- 
%
%               'Far-field response'
%
      h_calcffresp=uimenu(tmpobj,'Label','Far-field CW response', ...
	  'enable','off','Callback', ...
	  'ffmain(plotfig,elem_pts,flagg,media,excitation,transducer,centers);');

%
%
%               Array Analysis  
%

     h_calcanalysis = uimenu(tmpobj,'Label','Array Analysis');  

%
%              Curved/Linear
%
      h_calccurved = uimenu(h_calcanalysis,'Label','Curved/Linear Array', ...
	   'Callback',['method = ''curved'';','curved(transducer, excitation, media, flagg, plotfig,plotfigOrigHandle);']);
%
%               'Annular Array'
%

      h_calcannu = uimenu(h_calcanalysis,'Label','Annular Array');  
      uimenu(h_calcannu,'Label','Analysis','Callback',['method = ''annular'';',...
	  'figure(plotfig),aafile(transducer,excitation,media,flagg);'])
      uimenu(h_calcannu,'Label','Optimize # elements','Callback',...
	  '[transducer,elem_pts]=nusim(transducer,flagg,excitation,media);');
      uimenu(h_calcannu,'Label','Optimize diameter','Callback',...
	  '[transducer,elem_pts]=dusim(transducer,flagg,excitation,media);');

%
%               'Coarray tools'
%
      h_calccoar=uimenu(tmpobj,'Label','Coarray tools','Callback',...
	  ['coarray = coartool(coarray,elem_pts,transducer,option,media,', ...
	  'excitation,flagg,config,plotfig,plotfigOrigHandle);']);     
      
      
%
% MENUBAR: 'Print'
%
      tmpobj=uimenu(config,'Label','Print');
      uimenu(tmpobj,'Label','to PRINTER',...
	  'Callback','print');
      uimenu(tmpobj,'Label','to PostScript file',...
	  'Callback','print -deps usimtemp');
      uimenu(tmpobj,'Label','to PostScript file (Color)',...
	  'Callback','print -depsc usimtemp');
      uimenu(tmpobj,'Label','APPEND to PostScript file',...
	  'Callback','print -deps -append usimtemp');
      
      
%
% MENUBAR: 'Screen'
%
      tmpobj=uimenu(config,'Label','Screen');
      uimenu(tmpobj,'Label','Reset Screen','Callback',...
	  ['close(config);',...
	  'config=usimcnf(''initialize'');',...
	  'usimcnf(''update_allflags'',flagg,option);',...
	  'configOrigHandle=get(config,(''children''));']);
      uimenu(tmpobj,'Label','Clear Screen',...
	  'Callback','cleanscr(config,configOrigHandle);');
      uimenu(tmpobj,'Label','Reset Plots','Separator','on',...
	  'Callback','subplot(1,1,1);');
      
      
%
% Sub-MENUBAR: 'Subplot'
%
      tmpobj1=uimenu(tmpobj,'Label','Subplot');
      uimenu(tmpobj1,'Label','(1,1,1)','Callback','subplot(1,1,1);');
      tmpobj2=uimenu(tmpobj1,'Label','(2,1)');
      uimenu(tmpobj2,'Label','(2,1,1)','Callback','subplot(2,1,1);');
      uimenu(tmpobj2,'Label','(2,1,2)','Callback','subplot(2,1,2);');
      tmpobj2=uimenu(tmpobj1,'Label','(1,2)');
      uimenu(tmpobj2,'Label','(1,2,1)','Callback','subplot(1,2,1);');
      uimenu(tmpobj2,'Label','(1,2,2)','Callback','subplot(1,2,2);');
      tmpobj2=uimenu(tmpobj1,'Label','(1,3)');
      uimenu(tmpobj2,'Label','(1,3,1)','Callback','subplot(1,3,1);');
      uimenu(tmpobj2,'Label','(1,3,2)','Callback','subplot(1,3,2);');
      uimenu(tmpobj2,'Label','(1,3,3)','Callback','subplot(1,3,3);');
      tmpobj2=uimenu(tmpobj1,'Label','(2,2)');
      uimenu(tmpobj2,'Label','(2,2,1)','Callback','subplot(2,2,1);');
      uimenu(tmpobj2,'Label','(2,2,2)','Callback','subplot(2,2,2);');
      uimenu(tmpobj2,'Label','(2,2,3)','Callback','subplot(2,2,3);');
      uimenu(tmpobj2,'Label','(2,2,4)','Callback','subplot(2,2,4);');
      
      
%
% MENUBAR: 'Colormap'
%
      
%
% Checking the actual submenu is moved to setcomap.m
%
      tmpobj = uimenu(config,'Label','Colormap');
      h_colormap(1)=uimenu(tmpobj,'Label','bone','Callback','setcomap(config,1);');
      h_colormap(2)=uimenu(tmpobj,'Label','gray','Callback','setcomap(config,2);');
      h_colormap(3)=uimenu(tmpobj,'Label','pink','Callback','setcomap(config,3);');
      h_colormap(4)=uimenu(tmpobj,'Label','copper','Callback','setcomap(config,4);');
      h_colormap(5)=uimenu(tmpobj,'Label','cool','Callback','setcomap(config,5);');
      h_colormap(6)=uimenu(tmpobj,'Label','hot','Callback','setcomap(config,6);'); 
      h_colormap(7)=uimenu(tmpobj,'Label','hsv','Callback','setcomap(config,7);'); 
      h_colormap(8)=uimenu(tmpobj,'Label','jet','Callback','setcomap(config,8);'); 
      h_colormap(9)=uimenu(tmpobj,'Label','prism','Callback','setcomap(config,9);'); 
      h_colormap(10)=uimenu(tmpobj,'Label','flag','Callback','setcomap(config,10);'); 
      h_colormap(11)=uimenu(tmpobj,'Label','red','Callback','setcomap(config,11);'); 
      h_colormap(12)=uimenu(tmpobj,'Label','green','Callback','setcomap(config,12);'); 
      h_colormap(13)=uimenu(tmpobj,'Label','blue','Callback','setcomap(config,13);'); 
      h_colormap(14)=uimenu(tmpobj,'Label','white','Callback','setcomap(config,14);'); 
      h_colormap(15)=uimenu(tmpobj,'Label','black','Callback','setcomap(config,15);');
      
%
% MENUBAR: 'Shading'
%
      tmpobj = uimenu(config,'Label','Shading');
      h_shading(1)=uimenu(tmpobj,'Label','faceted','Callback','setshade(config,1);');
      h_shading(2)=uimenu(tmpobj,'Label','flat','Callback','setshade(config,2);');
      h_shading(3)=uimenu(tmpobj,'Label','interpolated','Callback','setshade(config,3);');
%
% MENUBAR: 'Help'
%
      tmpobj = uimenu(config,'Label','Help');
      tmpobj1=uimenu(tmpobj,'Label','User documentation','Callback', ....
			  'usimdoc(doc_command, ULTRASIMHOME);');        
      
%
% HANDLES
%
% Put handles in current figure's (config) UserData. 
% NB! When adding new handles to the list, append them after the last
% existing handle, or you have to update all references to h_list 
% (Routines depend on the handle index)
%

      h_list=[h_flagfmod ...            % 3 handles  - 1:3   extra hanldle for sub-array focusing 23.10.96, NAA
	  h_flagtgeo ...                % 2 handles  - 4:5
	  h_flagmedi ...                % 3 handles  - 6:8
	  h_flagcoor ...                % 4 handles  - 9:12
	  h_flagmmlambda ...            % 2 handles  - 13:14
	  h_flagobsv ...                % 4 handles  - 15:18  
	  h_calclayer ...               % 1 handle   - 19     
	  h_calcbp ...                  % 1 handle   - 20     
	  h_calcannu ...                % 1 handle   - 21  
	  h_calc2D ...                  % 1 handle   - 22  
	  h_calcresp ...                % 4 handles  - 23:26   
	  h_calccoar ...                % 1 handle   - 27      
	  h_colormap ...                % 15 handles - 28:42   
	  h_shading ...                 % 3 handles  - 43:45   
	  h_configtrans ...             % 5 handles  - 46:50  corrected from 4 to 5 handles 18.7.96 SH 
	  h_calcffresp ...              % 1 handle   - 51     From 3 to 1 handle SH 15.05.96  
	  h_flag3Dobsv ...              % 2 handles  - 52:53  Added for 3D KE 16/11
	  h_calc3dresp ...              % 2 handles  - 54:55  Added for 3D plots KE 24/1.96
	  h_calccurved];                % 1 handle   - 56     Added for curved array analysis, SH
%
% Store h_list in UserData, set window visible
% Restore backing (turned off during initialize for speed) 
%

      set(config,'UserData',h_list,'Backingstore','on','Visible','on');
	    
  end;  % if ACTION 'initialize'
  
  
  
% ********************************************************
%
%                       ACTION 'update_****flags'
%
% ********************************************************
  
  
%
%               'update_fmodflags' 
%
  if strcmp(ACTION,'update_allflags') | strcmp(ACTION,'update_fmodflags')
      
      config=findobj('Name','ULTRASIM - CONFIGURATION - CALCULATION');
      
      h_list=get(config,'UserData');            % get fmod handles
      h_flagfmod=h_list(1:3);                   % put actual handles in vector
      h_calcresp=h_list(23:26);
      set(h_flagfmod,'Checked','off');          % remove checking
      set(h_calcresp,'Enable','off');           % need to recalculate 2D resp

      if flagg(1)==1                            % set new checking Focus-Modes
	  set(h_flagfmod(1),'Checked','on');
	elseif flagg(1)==2
	  set(h_flagfmod(2),'Checked','on');
	elseif flagg(1)==3
	  set(h_flagfmod(3),'Checked','on');
      end;
  end;  % ACTION 'update_ ....flags'
      
  
%
%               'update_tgeoflags' 
%
  if strcmp(ACTION,'update_allflags') | strcmp(ACTION,'update_tgeoflags')
      
      config=findobj('Name','ULTRASIM - CONFIGURATION - CALCULATION');
      
      h_list=get(config,'UserData');            % get tgeo handles
      h_flagtgeo=h_list(4:5);                   % put actual handles in vector
      h_calclayer=h_list(19);
      h_calcannu=h_list(21);
      h_calcffresp=h_list(51);
      h_calcresp=h_list(23:26);
      h_configtrans=h_list(46:50);
      h_calccurved = h_list(56);
      set(h_flagtgeo,'Checked','off');          % remove checking
      set(h_calcresp,'Enable','off');           % need to recalculate 2D resp
      
      if flagg(2)==1                            % set new checking Transducer-Geometry 

	  set(h_flagtgeo(1),'Checked','on');    % Rectangular array
	  set([h_configtrans(1:5)],'Enable','on');
	  set([h_calclayer h_calcannu],'Enable','off');
	  set([h_calcffresp h_calccurved],'Enable','on');
	  
	elseif flagg(2)==3                      % Annular array 

	  set(h_flagtgeo(2),'Checked','on'); 
	  set([h_configtrans(1:5)],'Enable','off');      
	  set([h_calclayer h_calcannu],'Enable','on');
	  set([h_calcffresp h_calccurved],'Enable','off');
	  
      end;

  end;  % ACTION 'update_ ....flags'
      
  
%
%               'update_mediflags'
%
  if strcmp(ACTION,'update_allflags') | strcmp(ACTION,'update_mediflags')
      
      config=findobj('Name','ULTRASIM - CONFIGURATION - CALCULATION');
      
      h_list=get(config,'UserData');            % get medi handles
      h_flagmedi=h_list(6:8);                   % put actual handles in vector
      h_calcresp=h_list(23:26);
      set(h_flagmedi,'Checked','off');          % remove checking
      set(h_calcresp,'Enable','off');           % need to recalculate 2D resp
      
      if flagg(3)==1                            % set new checking Medium 
	  set(h_flagmedi(1),'Checked','on');
	elseif flagg(3)==2
	  set(h_flagmedi(2),'Checked','on');
	elseif flagg(3)==3
	  set(h_flagmedi(3),'Checked','on');
      end;
  end;  % ACTION 'update_ ....flags'
      
  
%
%               'update_coorflags'              
%
  if strcmp(ACTION,'update_allflags') | strcmp(ACTION,'update_coorflags')
      
      config=findobj('Name','ULTRASIM - CONFIGURATION - CALCULATION');
      
      h_list=get(config,'UserData');            % get coor handles
      h_flagcoor=h_list(9:12);                  % put actual handles in vector
      set(h_flagcoor,'Checked','off');          % remove checking
      
      if flagg(4)==1                            % set new checking Coordinates
	  set(h_flagcoor(1),'Checked','on');
	elseif flagg(4)==2
	  set(h_flagcoor(2),'Checked','on');
	elseif flagg(4)==3
	  set(h_flagcoor(3),'Checked','on');
	elseif flagg(4)==4
	  set(h_flagcoor(4),'Checked','on');
      end;
  end;  % ACTION 'update_ ....flags'
      
  
%
%               'update_mmlambdaflags'          
%
  if strcmp(ACTION,'update_allflags') | strcmp(ACTION,'update_mmlambdaflags')
      
      config=findobj('Name','ULTRASIM - CONFIGURATION - CALCULATION');
      
      h_list=get(config,'UserData');            % get mmlambda handles
      h_flagmmlambda=h_list(13:14);             % put actual handles in vector
      set(h_flagmmlambda,'Checked','off');      % remove checking
      
      if flagg(5)==1                            % set new checking Lambda/mm
	  set(h_flagmmlambda(1),'Checked','on');
	elseif flagg(5)==2
	  set(h_flagmmlambda(2),'Checked','on');
      end;
  end;  % ACTION 'update_ ....flags'
      
  
%
%               'update_obsvflags' 
%
  if strcmp(ACTION,'update_allflags') | strcmp(ACTION,'update_obsvflags')
      
      config=findobj('Name','ULTRASIM - CONFIGURATION - CALCULATION');
      
      h_list=get(config,'UserData');            % get all handles
      h_flagobsv=h_list(15:18);                 % put actual handles in vector
      h_calcbp=h_list(20);
      h_calc2D=h_list(22);
      h_calcresp=h_list(23:26);
% -----------------------
% Added KE 16/11
      h_flag3Dobsv=h_list(52:53);               % changed address SH 15.05.96 & 17.07.96
% -----------------------
      set(h_flagobsv,'Checked','off');          % remove checking
% -----------------------
%Added KE 16/11
      set(h_flag3Dobsv,'Checked','off');
% -----------------------
      set(h_calcresp,'Enable','off');           % need to recalculate 2D resp
      
      if option(1)=='p'                         % set new checking Observation
	  set(h_flagobsv(1),'Checked','on');
	  set(h_calcbp,'Enable','on');
	  set(h_calc2D,'Enable','off');
	elseif option(1)=='1'
	  set(h_flagobsv(2),'Checked','on');
	  set(h_calcbp,'Enable','on');
	  set(h_calc2D,'Enable','off');
	elseif option(1)=='2'
	  set(h_flagobsv(3),'Checked','on');
	  set(h_calcbp,'Enable','off');
	  set(h_calc2D,'Enable','on');
	elseif option(1)=='m'
	  set(h_flagobsv(4),'Checked','on');
	  set(h_calcbp,'Enable','off');
	  set(h_calc2D,'Enable','on');
% ------------------------------------
% Added KE 16/11
	elseif option(1)=='3'
	  set(h_flag3Dobsv(1),'Checked','on');
	  set(h_calcbp,'Enable','off');
	  set(h_calc2D,'Enable','on');
	elseif option(1)=='f'
	  set(h_flag3Dobsv(2),'Checked','on');
	  set(h_calcbp,'Enable','off');
	  set(h_calc2D,'Enable','on');
      end;
% ------------------------------------
      
  end;  % ACTION 'update_ ....flags'
      
  
  
% ********************************************************
%
%                       ACTION 'update_calcresp'
%
% ********************************************************
  
  
  if strcmp(ACTION,'update_calcresp')
      
      config=findobj('Name','ULTRASIM - CONFIGURATION - CALCULATION');
      h_list=get(config,'UserData');            % get calcresp handles
      h_calcresp=h_list(23:26);                 % put actual handles in vector
      set(h_calcresp,'enable','off');           % disable all
      
% ---------------------------------------
% Added for 3D by KE 24.01.96
      h_calc3dresp=h_list(54:55);               % changed addresses SH 15.05.96 & 17.07.96
      set(h_calc3dresp,'enable','off');
% ---------------------------------------


%
% Surface plot, Contour plot, image plot requires a calculation and 
% a plane - option(1) == '2', movie - option(1) == 'm' 
%
      if option(1) == '2'
	  set([h_calcresp(1) h_calcresp(3:4)],'enable','on');
	elseif option(1) == 'm'
	  set([h_calcresp(2) h_calcresp(3)],'enable','on');
% ---------------------------------------
% Added for 3D sim  by KE
	elseif option(1) == '3'                                   %
	  set(h_calc3dresp(1),'enable','on');    
	elseif option(1) == 'f'                                   % KE 24/1/96
	  set(h_calc3dresp(2),'enable','on');                     %
      end
% ---------------------------------------
      
  end;  % ACTION 'update_calcresp'
  
  
  
% ********************************************************
%
%                       ACTION 'update_colormap'
%
% ********************************************************
  
  
  if strcmp(ACTION,'update_colormap')
      
      config=findobj('Name','ULTRASIM - CONFIGURATION - CALCULATION');
      h_list=get(config,'UserData');            % get calcresp handles
      h_colormap=h_list(28:42);                 % put actual handles in vector
      
      set(h_colormap,'checked','off');          % uncheck all
      set(h_colormap(num),'checked','on');      % check actual
      
  end;  % ACTION 'update_colormap'
  
  
  
% ********************************************************
%
%                       ACTION 'update_shading'
%
% ********************************************************
  
  
  if strcmp(ACTION,'update_shading')
      
      config=findobj('Name','ULTRASIM - CONFIGURATION - CALCULATION');
      h_list=get(config,'UserData');            % get calcresp handles
      h_shading=h_list(43:45);                  % put actual handles in vector
      
      set(h_shading,'checked','off');           % uncheck all
      set(h_shading(num),'checked','on');       % check actual
      
  end;  % ACTION 'update_shading'
  
