function cosFactor = cos_fact(x0,y0,z0,transducer,flagg,xobs,yobs,zobs,cosflagg)
%------------------------------------------------------------------------------
% Routine         : cosFactor = 
%                   cos_fact(x0,y0,z0,transducer,flagg,xobs,yobs,zobs,cosflagg)
% Description     : Calculate cos of the angle between the rays from the transducer
%                   (x0,y0,z0) and to the observation points (xobs,yobs,zobs),
%                   and the vector normal to the transducer at point (x0,y0,z0)
%                   cosflagg=1 => cos_corr=cos(angle)
%                   cosflagg=2 => cos_corr=(1+cos(angle))/2
% Language        : Matlab 5.0
% Written by      : Lars Odegaard
% Version no.     : 1.0 LO 8/6-98
% Called by       : pec
% Routines called : normal
%----------------------------------------------------------------------------- 

tmpflagg=0;


if flagg(2)==3  %annular transducer
   F=transducer(9);
   htype=[2,F,F,F,1,0];
   tmpflagg=1;
   [nx,ny,nz] = normal(x0,y0,z0,htype,0);
end     


if flagg(2)==1 % 1D 1.5D og 2D rektangular transducer
   
   % azimuth fixed focus
   Fxzplane=transducer(17); 
   if Fxzplane==0
      Fxzplane=1000000;
   end
   
   % elevation fixed focus
   Fyzplane=transducer(9);  
   if (transducer(6)==3)|(transducer(6)==5) % 3 or 5 elevation elements
      if (transducer(6)==3)&(abs(y0)>(transducer(12)/2))         
         Fyzplane=transducer(11);
      elseif (transducer(6)==5)&(abs(y0)>(transducer(12)/2+transducer(13)))
         Fyzplane=transducer(11)
      elseif (transducer(6)==5)&(abs(y0)>(transducer(12)/2))
         Fyzplane=transducer(10)
      else 
      end       
   end      
   
   % calculate vector normal to transducer at (x0,y0,z0))
   % calculate ny:
   htype1=[2,1000000,abs(Fyzplane),abs(Fyzplane),sign(Fyzplane),0];
   [nx1,ny1,nz1] = normal(x0,y0,z0,htype1,0);
   ny=ny1/nz1;
   % calculate nx:
   htype2=[2,abs(Fxzplane),1000000,abs(Fxzplane),sign(Fxzplane),0];
   [nx2,ny2,nz2] = normal(x0,y0,z0,htype2,0);
   nx=nx2/nz2;
   %
   nz=1;
   nr=sqrt(nx^2+ny^2+nz^2);
   nx=nx/nr;
   ny=ny/nr;
   nz=nz/nr;            
   tmpflagg=1;
end


% Calculate ray from transducer point (x0,y0,z0) and observation points 
% (xobs,yobs,zobs)
if tmpflagg==1
   xout = xobs - x0;  
   yout = yobs - y0;
   zout = zobs - z0;
   r = sqrt(xout.^2 + yout.^2 + zout.^2);
   xout = xout./r;
   yout = yout./r;
   zout = zout./r;
   if cosflagg==1
     cosFactor=xout.*nx + yout.*ny + zout.*nz;
   elseif cosflagg==2  
     cosFactor=(1+xout.*nx + yout.*ny + zout.*nz)/2;
   else
     cosFactor=1;  
     disp('Warning 1 from cos_fact: cosfactor not included')
   end     
else
   cosFactor=1;
   disp('Warning 2 from cos_fact: cosfactor not included')
end

   




