#include <stdio.h>
#include <math.h>
#include <string.h>
#include "mat.h"
#include "mex.h"


#define PI 3.14159265358979
#define EPS 2.220446049250313e-16
#define INF 1e308
#define MAXTASKS 32

struct ans 
{ Matrix *rsp;
  Matrix *maxrp;
  Matrix *minrp;};


/* Help function to find the non conjugate transpose 
   of a matrix */
Matrix *non_conj_transpose(mtradr)
     Matrix *mtradr;
{
   int m,n,i,j;
  double *pr,*pi,*tpr,*tpi;
  Matrix *temp;

  m=mxGetM(mtradr);
  n=mxGetN(mtradr);
  pr=mxGetPr(mtradr);
  pi=mxGetPi(mtradr);

  temp=mxCreateFull(n,m,mxIsComplex(mtradr));
  tpr=mxGetPr(temp);
  tpi=mxGetPi(temp);

  for (i=0;i<m;i++)
    for (j=0;j<n;j++)
      {
        tpr[n*i+j]=pr[m*j+i];
        if (mxIsComplex(temp))
          tpi[n*i+j]=pi[m*j+i];
      } 
  return temp;
}

/* Help function to convert a number to a string */

char *num2str(val)
     int val;
{
  int ch;
  char aval[4];
  char *sval;


  ch=(val/100);
  val=val % 100;
  aval[0]=ch+48;
  ch=(val/10);
  val=val % 10;
  aval[1]=ch+48;
  ch=val;
  aval[2]=ch+48;
  aval[3]='\0';
  sval=aval;
  return sval;
}

/* Help function to get the absolute value of a real number */

double abs_val(val)
     double val;
{
  if (val<0)
    val=-1*val;
  return val;
}

/* Main Calculation Routine in Mex file */
struct ans pec(x,y,z,t,FieldSize,elem,ElPt,Apodize,excitation,
	       SteerFocusDelay,TimeStepVector,trans,fla,
	       option,usr_resdir,values,cent,tasks)
     
     double x[],y[],z[],t[],Apodize[],excitation[];
     double SteerFocusDelay[],TimeStepVector[],values[];
     Matrix *elem,*trans,*fla,*cent;
     char option[],usr_resdir[];
     int FieldSize[],ElPt[],tasks;


{
  double r,c,PulseLength,jomega,TLen,*transducer,*flagg;
  double *elem_pts,*Time,Weight,*resp_pr,*resp_pi;
  double *maxpr,*minpr;
  Matrix *resp,*temp,*input,*c_foc,*rhs[6],*lhs[2];
  double d,d_max,foc_depth,f_number,*input_pr,*c_foc_pr;
  int min_elem,max_elem;

  int PNo,FieldLength,n,a,i,finite,testint,k,ulen,set;
  double t_ref,x0,y0,z0,maxt,mint,TStFo,TimeDel,w_pulse;
  double t_vector,r_attenu,trans_arr_value,F_des;
  char *mtrname,*filename;
  char mtn[10];
  char fn[80];
  char *conv,*Pict,*mat;
  MATFile *fp;


  int numt,tids[MAXTASKS],data_len,residual,cc,id,len,bl;
  int mytid,lstart,lend,elems,NTASK;
  double *l_pr,*l_pi;
  char buf[10];int tata;
  /* Structure definition used when extracting the three 
     solution matrices. */
  
  struct ans reply;


  /* List of variables imported from pecomp.m, that are 
     used in the mex file */
  printf("\n** COMPUTING RESPONSE IN PARALLEL SYSTEM **\n\n");
  if ((option[0] == 'm') || (option[0] =='f'))
    {

      Pict="Pict";
      mat=".mat";
      mtn[0]='P';mtn[1]='i';mtn[2]='c';mtn[3]='t';
      mtn[4]='0';mtn[5]='0';mtn[6]='0';mtn[7]='\0';
      ulen=0;
      ulen=strlen(usr_resdir);
      for (k=0;k<ulen+12;k++){
	if (k<ulen)
	  fn[k]=usr_resdir[k];
	else if (k<ulen+7)
	  fn[k]=mtn[k-ulen];
	else 
	  fn[k]=mat[k-ulen-7];
      }
   
      filename=fn;
      mtrname=mtn;
    }
  flagg=mxGetPr(fla);
  transducer=mxGetPr(trans);
  elem_pts=mxGetPr(elem);
  r=values[0];
  c=values[1];
  PulseLength=values[2];
  TLen=values[3];
  jomega=values[4];
  Weight=values[5];
  trans_arr_value=values[6];
  F_des=values[7];

  d=transducer[0];

  FieldLength=FieldSize[0]*FieldSize[1];


  /* Creatingmax_resp and min_resp. */

  reply.maxrp=mxCreateFull(1,2,REAL);
  maxpr=mxGetPr(reply.maxrp);
  reply.minrp=mxCreateFull(1,2,REAL);
  minpr=mxGetPr(reply.minrp);
  maxpr[0]=0;maxpr[1]=0;
  minpr[0]=0;minpr[1]=0;


  /* Time reference or distance reference */

  if ((option[2]=='y') || (option[2]=='z'))
    t_ref=t[0];
  else
    t_ref=r/c;



  NTASK=tasks;


  /* Enroll in PVM   */

  mytid=pvm_mytid(); 


  /* Call PVM : Spawn ppec_slave */

  numt=pvm_spawn("ppec_slave",0,0,"",NTASK,&tids);

  printf("%d host(s) activated\n",numt); 

  /* Check if Z is finit */
  finite=0;
  for (i=0;i<FieldLength;i++)
    if ((z[i]<INF) && (z[i]>-INF))
      {finite=1;break;}

  printf("Starting Calculations....\n");

  /* Data distribution parameters  */
  
  data_len=(int)FieldLength/numt;
  residual=FieldLength-data_len*numt;

  /* LOOP OVER TIME REFERENCES */

  for (PNo=1;PNo<=TLen;PNo++)
    {
      
      /* put time array into a vector. Due to the array 
	 nature of t, no reshaping is done when making 
	 the Time array. */

      if ((option[0]=='m') || (option[0]=='f'))
	{
	  temp=mxCreateFull(1,FieldLength,REAL);
	  Time=mxGetPr(temp);
	  for (i=0;i<FieldLength;i++)
	    Time[i]=TimeStepVector[PNo-1];
	}
      else
	Time=t;
      d_max=d;
      min_elem=1;
      max_elem=ElPt[1];

      /* If Dynamic Focus and Movie, 
	 find SteerFocusDelays for time step */

      if ((flagg[0]==2) && 
	  ((option[0]=='m') || (option[0]=='f')))
	{
	  foc_depth=c*TimeStepVector[PNo-1];
	  if (F_des > 0)
	    {
	      if (d<foc_depth/F_des)
		d_max=d;
	      else
		d_max=foc_depth/F_des;
	      max_elem=0;
	      min_elem=ElPt[1];
	      for (set=0;set<ElPt[1];set++)
		if (abs_val(elem_pts[set*5])<=d_max/2)
		  { 
		    if (max_elem<set+1)
		      max_elem=set+1;
		    if (min_elem>set+1)
		      min_elem=set+1;
		  }
	      if (F_des>foc_depth/d_max)
		f_number=F_des;
	      else
		f_number=foc_depth/d_max;
	      printf("f-number: %3.0f, aperture: %5.2f mm, element rage: %d-%d\n",
		     f_number,d_max*1000,min_elem,max_elem);
	    }
	  else
	    d_max=d;


	  /* Call ULTRASIM Routine -focus-. */

	  input=mxCreateFull(1,7,REAL);
	  input_pr=mxGetPr(input);
	  for (i=0;i<7;i++)
	    input_pr[i]=excitation[i];
	  input_pr[1]=foc_depth;

	  c_foc=mxCreateFull(1,1,REAL);
	  c_foc_pr=mxGetPr(c_foc);
	  c_foc_pr[0]=excitation[13];
	  rhs[0]=input;rhs[1]=c_foc;rhs[2]=trans;
	  rhs[3]=elem;rhs[4]=cent;rhs[5]=fla;
	  mexCallMATLAB(2,lhs,6,rhs,"focus");
	  SteerFocusDelay=mxGetPr(lhs[0]);
	}
	
	      

      /* Initialize */

      if (PNo>1)
	mxFreeMatrix(resp);
      resp=mxCreateFull(1,FieldLength,COMPLEX);
      resp_pr=mxGetPr(resp);
      resp_pi=mxGetPi(resp);




      /* COMPUTING RESPONSE IN PARALLEL PROGRAMMING. */

      /* OBSERVATION POINTS */

      if (numt !=1)
	{
	  lend=-1;
	  for (i=0;i<numt;i++)
	    {
	      lstart = lend+1;
	      if (i<residual)
		lend = lstart + data_len;
	      else
		lend = lstart + data_len - 1;

	      pvm_initsend(0);  	       
	      pvm_pkint(&lstart,1,1);
	      pvm_pkint(&lend,1,1);
	      pvm_pkint(&PNo,1,1);
	      pvm_pkint(&min_elem,1,1);
	      pvm_pkint(&max_elem,1,1);
	      pvm_pkint(&ElPt[0],2,1);
	      pvm_pkdouble(&SteerFocusDelay[0],ElPt[1],1);
	      pvm_pkdouble(&Time[lstart],lend-lstart+1,1);	  
	      if (PNo == 1)
		{ 
		  pvm_pkint(&FieldLength,1,1);
		  pvm_pkint(&finite,1,1);  
		  pvm_pkdouble(&t_ref,1,1);
		  pvm_pkdouble(&c,1,1);
		  pvm_pkdouble(&jomega,1,1);
		  pvm_pkdouble(&Weight,1,1);  
		  pvm_pkdouble(&PulseLength,1,1);
		  pvm_pkdouble(&elem_pts[0],ElPt[0]*ElPt[1],1);
		  pvm_pkdouble(&Apodize[0],ElPt[1],1);
		  pvm_pkdouble(&x[lstart],lend-lstart+1,1);
		  pvm_pkdouble(&y[lstart],lend-lstart+1,1);
		  pvm_pkdouble(&z[lstart],lend-lstart+1,1);
		} 
	      pvm_send(tids[i],3);
	    }
	}

      for (i=0;i<numt;i++)
	{
	  cc=pvm_recv(-1,-1);
	  pvm_bufinfo(cc,(int*)0,(int*)0,&id);
	  pvm_upkint(&lstart,1,1);
	  pvm_upkint(&lend,1,1);
	  len=lend-lstart+1;
	  l_pr=(double *)calloc(len,sizeof(double));
	  l_pi=(double *)calloc(len,sizeof(double));
	  pvm_upkdouble(l_pr,len,1);
	  pvm_upkdouble(l_pi,len,1);
	  for (bl=lstart;bl<=lend;bl++)
	    {
	      resp_pr[bl]=l_pr[bl-lstart];
	      resp_pi[bl]=l_pi[bl-lstart];
	    }
	  /*	  printf("Received from %x host\n",id); */
	  printf("Calculation completed %d of %d hosts.  \r",
		 i+1,numt);   
	  cfree(l_pr);
	  cfree(l_pi);
	}
      printf("\n");
  
      printf("Loop %d of %3.0f now at %d of totally %d computations\n",
	     PNo,TLen,max_elem,ElPt[1]);

      /* Put the response into a matrix */
      mxSetM(resp,FieldSize[0]);
      mxSetN(resp,FieldSize[1]);

      for (i=0;i<FieldLength;i++)
	{

	  /* Normalize response */
	  resp_pr[i]=resp_pr[i]*trans_arr_value;
	  resp_pi[i]=resp_pi[i]*trans_arr_value;


	  /* Compute max and min of response.*/
	  if (maxpr[0]<resp_pr[i])
	    maxpr[0]=resp_pr[i];
	  if (maxpr[1]<resp_pi[i])
	    maxpr[1]=resp_pi[i];
	  if (minpr[0]>resp_pr[i])
	    minpr[0]=resp_pr[i];
	  if (minpr[1]>resp_pi[i])
	    minpr[1]=resp_pi[i];
	}
      resp=non_conj_transpose(resp);

      if ((option[0]=='m') || (option[0]=='f'))
	{
	  conv=num2str(PNo);
	  for (k=4;k<7;k++)
	    mtn[k]=conv[k-4];
	  for (k=0;k<7;k++)
	    fn[k+ulen]=mtn[k];
	  mxSetName(resp,mtrname);
	  fp= matOpen(filename,"w");
	  matPutMatrix(fp,resp);
	  matClose(fp); 
	}
    }      

  lstart=-1;
  for (i=0;i<numt;i++)
    {
      pvm_initsend(0);
      pvm_pkint(&lstart,1,1);
      pvm_send(tids[i],3);
    }



  pvm_exit();
  reply.rsp=resp;
  return reply;
}



/* MEX Gateway function  */

#ifdef __STDC__
void mexFunction(
		 int nlhs,
		 Matrix  *plhs[],
		 int nrhs,
		 Matrix  *prhs[]
		 )
#else
mexFunction (nlhs,plhs,nrhs,prhs)
     int nlhs,nrhs;
     Matrix *plhs[],*prhs[];
#endif

{
  Matrix *trans,*fla,*elem,*cent;
  double *x,*y,*z,*t,*Apod,*excit,*temp,*SFD,*TSV;
  int FS[2],EP[2],n,task;
  char *opt,*dirpath,*delim,*usr_resdir;
  struct ans mtr;


  x=mxGetPr(prhs[0]);  
  FS[0]=mxGetM(prhs[0]);FS[1]=mxGetN(prhs[1]);
  y=mxGetPr(prhs[1]);
  z=mxGetPr(prhs[2]);
  t=mxGetPr(prhs[3]);
  elem=prhs[4];
  EP[0]=mxGetM(prhs[4]);EP[1]=mxGetN(prhs[4]);
  Apod=mxGetPr(prhs[5]);
  excit=mxGetPr(prhs[6]);
  SFD=mxGetPr(prhs[7]);
  TSV=mxGetPr(prhs[8]);
  trans=prhs[9];
  fla=prhs[10];
  
   
  n=mxGetN(prhs[11])+1;
  opt=mxCalloc(n,sizeof(char));
  mxGetString(prhs[11],opt,n);

  n=mxGetN(prhs[12])+1;
  dirpath=mxCalloc(n,sizeof(char));
  mxGetString(prhs[12],dirpath,n);

  n=mxGetN(prhs[13])+1;
  delim=mxCalloc(n,sizeof(char));
  mxGetString(prhs[13],delim,n);

  usr_resdir=strcat(dirpath,delim);

  temp=mxGetPr(prhs[14]);
  cent=prhs[15];
  printf("-> Enter the number of tasks [<=32] : ");
  scanf("%d",&task);
  mtr=pec(x,y,z,t,FS,elem,EP,Apod,excit,SFD,TSV,trans,
	  fla,opt,usr_resdir,temp,cent,task);
  

  plhs[0]=mtr.rsp;
  plhs[1]=mtr.maxrp;
  plhs[2]=mtr.minrp;
  
}
