%------------------------------------------------------------------------
% Routine     : setdelay.m
%
% Description : Menu for manually setting electronic time delays on the
%               elements of a transducer (constflag = 0), or adding a
%               constant electronic time delay to the dealys calculated by
%               the ordinary focusing algorithm (constflag =1). Works only
%               when dynamic focus and 2D media flags are set. 
%
% Language    : Matlab 4.1
% Written by  : Frode Teigen, IBT
%
% Version no. : 3.0 FT 15.02.94 First Version
%
% Called by   : bdynusim
% Calling     : delsize
%------------------------------------------------------------------------

function delay = setdelay(tekst,delay,transducer,constflag)

clc
delay = delsize(delay,transducer);	% Verifying that length of delay
                                        % vector equals # transducer elements
tmpsize = size(delay);
fid = 1;
if ~constflag
  disp([' Set time delays for ',tekst,' focusing :']);
  disp('----------------------------------------')
  disp(' ');
  disp([' Vector for 1 focal zone must have length ',int2str(tmpsize(2)),...
       ', and have the following format : ']);
  disp([' [ rstart[mm] rstop[mm] delay#1[ns]  . . . delay#',...
	      int2str(tmpsize(2)-2),'[ns] ]']);
else
  disp([' Set delay constants for ',tekst,' focusing :']);
  disp('----------------------------------------')
  disp(' ');
  disp([' Vector for delay constants must have length ',...
	    int2str(tmpsize(2)-2),', and have the following format : ']);
  disp([' [ const#1[ns]  . . . const#',...
	      int2str(tmpsize(2)-2),'[ns] ]']);
end
zone = 1;
tmpvect = 1;
while (length(tmpvect)~=1 | tmpvect~=0) & (~constflag | zone==1)
  if zone > tmpsize(1)
    default = zeros(1,tmpsize(2));
  else
    default = delay(zone,:);
    default(1:2) = default(1:2)*1e3;
    default(3:length(default)) = default(3:length(default))*1e9;
  end
  if constflag
    default = default(3:length(default));
  end
  if ~constflag
    fprintf(fid,'\n Zone #%2.0f \n ',zone);
    fprintf(fid,'========\n')
  end
  fprintf(fid,' Default = [%6.2f ',default(1));
  for n = 2:length(default)
    fprintf(fid,'%6.2f',default(n));
  end
  fprintf(fid,'] \n');
  fprintf(fid,' <CR> = default \n');
  if ~constflag
    fprintf(fid,'  0  = No more zones (minimum 1 zone)');
    tmpvect = input (' Type vector/<CR>/0 : ');
  else
    tmpvect = input (' Give vector of constants/<CR> : ');
  end    
  if isempty(tmpvect)
    if ~constflag
      delay(zone,1:2) = default(1:2)*1e-3;
      default = default(3:length(default));
    end
    delay(zone,3:size(delay,2)) = default*1e-9;
    zone = zone + 1;
  elseif length(tmpvect)==length(default)
    if ~constflag
      delay(zone,1:2) = tmpvect(1:2)*1e-3;
      tmpvect = tmpvect(3:length(tmpvect));
    end
    delay(zone,3:size(delay,2)) = tmpvect*1e-9;
    zone = zone + 1;
  elseif tmpvect==0 & zone==1
    tmpvect = 1;
  end
end
if (zone - 1)<tmpsize(1) & ~constflag
  delay = delay(1:(zone - 1),:);
end
  
