%------------------------------------------------------------------------
% Routine         : partxt        
%
% Description     : Returns information on the parameters used to 
%		    describe a function in a layered model.
%
% Language        : Matlab 4.1
% Written by      : Frode Teigen (IBT)
%
% Version no.     : 1.0 FT 07.01.94
%		  : 1.5 FT 02.02.94 Added function class 5
%                   1.6 EH dec 95   Added function class 6
%                   1.7 EH 22.12.95 Changed parameters of surf. type 6
%                   1.8 EH 19.02.95 Added function class 7 
%     
% Called by       : musim
% Routines called : none
%------------------------------------------------------------------------

function Y = partxt(ftype,flagg,x)

if ftype==1
   if x=='e'
	Y = 'e (not used)';
   else
   	Y = x;
   end
elseif ftype==2
   if x=='a'
       	Y = 'Radius in x-direction :                        a [mm]';
   elseif x=='b'
	if flagg(3)==2
	   Y = 'Radius in z-direction :                        b [mm]';
	else
	   Y = 'Radius in y-direction :                        b [mm]';
	end
   elseif x=='c'
	if flagg(3)==2
	   Y = 'Right (c=-1) or Left (c=1) Half of Ellipsoid?  c     ';
	else
	   Y = 'Radius in z-direction :                        c [mm]';
	end
   elseif x=='d'
	if flagg(3)==2
	   Y = 'z-offset :                                     d [mm]';
	else
	   Y = 'Right (d=-1) or Left (d=1) Half of Ellipsoid?  d     ';
	end
   elseif x=='e'
	Y = 'z-offset (not used) :                          e [mm]';
   end
elseif ftype==3

elseif ftype==4
   if x=='d'
	Y=[x,'     '];
   else
 	Y=[x,' [mm]'];
   end
elseif ftype==5
   if x=='a'
	Y = 'Variable Number      : a';
   elseif x=='b'
 	Y = 'Interpolation Method : b';
   else
	Y = [x,' (not used)            '];
   end
elseif ftype==6 
%                   warped:    [  3  ,   sn,   x0,    y0,        a,   l ]

%                   warped:   sn = surface mesh no. (in glob. var. smeshes)
%                             x0,y0 = position of centre of mesh in xy plane
%                             a =  (peak) amplitude of h
%                             l = lenght of side of rect. wapred region
%
   if x=='a'
	Y = 'Surface mesh no.   : a';
   elseif x=='b'
 	Y = 'x-translation      : b';
   elseif x=='c'
 	Y = 'y-translation      : c';
   elseif x=='d'
 	Y = 'amplitude scaling  : d';
   else
	Y = [x,' (not used)            '];
   end

elseif ftype==7 
   if x=='a'
	Y = 'length in x-direction    : a';
   elseif x=='b'
	Y = 'length in y-direction    : b';
   elseif x=='c'
 	Y = '# periods in x-direction : c';
   elseif x=='d'
 	Y = '# periods in y-direction : d';
   else
 	Y = 'amplitude                : e';
   end

else
   disp(' ***ERROR : functype not identified***');
end





