%------------------------------------------------------------------------
% Routine	  : vwexci.m
%
% Description     : Plotting a view of the signal defined by the excitation 
%                   menu, the spectrum is also plotted
%
% Language        : Matlab 4.1
% Written by      : Vebjorn Berre, IBT
%
% Version no.     : 2.0 VEB 14.04.93
% Version no.     : 3.0 SH  07.05.93
% Version no.     : 3.1 FT  10.08.93
% Version no.     : 3.2 FT  27.09.93 Changed cos into sin
% Version no.	  : 3.3 FT  06.01.94 Added comments 
%                   3.4 FT  28.02.94 Increased resolution of freq.spectrum
%                   3.5 FT  23.03.94 Included User-defined pulse
%                   3.6 SH   9. 1.95 Added output of Q-factor
%                   3.7 SH   6.02.95 Output of relative bandwidth
%
% Called by       : usimcnf
%------------------------------------------------------------------------

function Y=vwexci(excitation,flagg,s,plength)

osc=excitation(9);
f=excitation(1);
if (finite(osc) & osc ~= 0) | excitation(13)
  subplot(2,1,1),
  pw=excitation(10);
  if excitation(12) 			% Quantizing on
    Fs=excitation(11);
  else 					% Quantizing off
    Fs = 50*f;
  end
  if ~excitation(13)
    plen=osc/f;
    tstep=1/Fs;
  
    t=[0:tstep:plen];
    if rem(osc,2) == 0, 	  % in beampat, t=0 is in the middle of the
      s=sin(2*pi*f*t);	 	  % pulse. Therefore the pulses of an even
    else 			  % no. of osc. will start with a positive
      s = sin(2*pi*f*t + pi); 	  % slope, while the pulses of an odd no. of
    end 			  % osc. starts with a negative slope.
    if pw==1
      senv=sin(pi*t/plen);
      s=senv.*s;
      plot(t*1e6,s,'-',t*1e6,senv,'--',t*1e6,-senv,'--')
    else
      plot(t*1e6,s,'-')
    end
  else
    tstep = plength/1000;
    t=0:tstep:plength;
    plot(t*1e6,s)
  end
  xlabel('time [microseconds]')
  ylabel('Relative signal level')
  title('Transmitted pulse')
  grid
%
% find spectrum of transmitted pulse
% added 7 May 1993 SH
%
	Nfft = 1024;
	if ~excitation(13)
	  if 4*f*tstep<1 		% Fsample>4*f
	    Nfft = fix(1024/(4*f*tstep));
	    if rem(Nfft,2) 		% fft is very slow if Nfft is odd.
	      Nfft = Nfft + 1;   
	    end
	  end
	else
	  Nfft = 1024;  
	end
	S = fft(s,Nfft);
%
% plot up to 4*center frequency
%
	maxindex = 1024;
	pick = 1:maxindex;
 	Sxx = abs((S(pick)));
	maxSxx = max(Sxx);
	Sxx = Sxx/maxSxx;
	subplot(2,1,2)
	freq = (pick-1)/(tstep*Nfft);
%
% find Q-factor, defined by ratio of center frequency and -3 dB bandwidth:
%
	bw_index = find(Sxx > max(Sxx)/sqrt(2));
        Q = f*tstep*Nfft/length(bw_index-1);
	
%
% find relative -6 dB bandwidth
%
	bw_index = find(Sxx > max(Sxx)/2);
        rel_bw = length(bw_index-1)/(f*tstep*Nfft);
	
	plot(1e-6*freq,20*log10(Sxx))
 	xlabel(['Frequency [MHz], Q: ',num2str(Q),', bw (-6 dB): ',num2str(100*rel_bw),'%'])
	ylabel('dB')
	grid
	ax = axis;
	if ~excitation(13)
	  axis([ax(1) ax(2) -60 0]) 
	else
	  axis([0 4*f/1e6 -60 0])
	end

else 
  disp(['CW, frequency = ', num2str(f*1e-6),' MHz']);
end





