%------------------------------------------------------------------------
% Routine         : vwtrfcy2.m
%
% Description     : View of transducer, fancy version. 
%                   Supports triangular (hexagonal) grid.
%
% Language        : Matlab syntax
% Written by      : Vebjorn Berre
% Version no.     : 3.0 VEB 01.04.93
% Modified        : 3.1 BJE 23.04.95 Removed colormap 
%
% Called by       : usimcnf
% Calls           : sort2
%------------------------------------------------------------------------

function Y=vwtrfcy2(transducer,elem_pts)
  
  disp('WAIT CALCULATING SURFACE ........')
      
  [Y,I]=sort2(elem_pts([2 1],:));
  hexgrid=elem_pts([1 2 3],I);
  
  N=length(elem_pts(1,:));
  rectgrid(:,[1:2:2*N])=hexgrid;
  rectgrid(:,[2:2:2*N])=hexgrid;
  
  x=rectgrid(1,:);
  y=rectgrid(2,:);
  z=rectgrid(3,:);
  nn=length(find(y==0))+2;
  
% memory allocation temporary set nyx, nyy and nyz
%nyx=ones(1,nn*nn);
%nyy=nyx;
%nyz=nyx;
  
  ctx=0;
  lastind=0;
  while lastind<length(x)
      ctx=ctx+1;
      tmpind=find(y==y(lastind+1));
      ind=[tmpind(1):1:tmpind(length(tmpind))];
      ltmp=(nn-length(ind))/2;
      
      nyx([(ctx-1)*nn+1:1:ctx*nn])=[x(ind(1))*ones(1,ltmp)  x(ind) x(ind(length(ind)))*ones(1,ltmp) ];
      nyy([(ctx-1)*nn+1:1:ctx*nn])=[y(ind(1))*ones(1,ltmp)  y(ind) y(ind(length(ind)))*ones(1,ltmp) ];
      nyz([(ctx-1)*nn+1:1:ctx*nn])=[z(ind(1))*ones(1,ltmp)  z(ind) z(ind(length(ind)))*ones(1,ltmp) ];
      lastind=ind(length(ind));
  end
  
  disp('WAIT PLOTTING........')
      
  subplot(1,1,1)
  xx=reshape(nyx,nn,ctx);
  yy=reshape(nyy,nn,ctx);
  zz=reshape(nyz,nn,ctx);
  
%
% modified to plot lightning model and 
% to set axis so that min 1 mm in z-direction is shown
%   
  surfl(1000*xx',1000*yy',1000*zz')
  
  v=axis;
  v(5) = min(v(5),-1);
  v(6) = max(v(6),1);
  axis(v);
  
  xlabel('x'),ylabel('y'),zlabel('z');
  
  disp('Finished!');
  disp('Enter ''uitrsd'' to get pop-ups and sliders for controlling the plot');
  fprintf('\n');
